@@ -188,14 +188,35 @@ REST_API_VERSION_HISTORY = """
     * 2.71 - Added 'updated_at' field in share instance show API output.
     * 2.72 - Added new option ``share-network`` to share replica creare API.
     * 2.73 - Added Share Snapshot Metadata to Metadata API
-
+    * 2.74 - Allow/deny share access rule even if share replicas are in
+             'error' state.
+    * 2.75 - Added option to specify quiesce wait time in share replica
+             promote API.
+    * 2.76 - Added 'default_ad_site' field in security service object.
+    * 2.77 - Added support for share transfer between different projects.
+    * 2.78 - Added Share Network Subnet Metadata to Metadata API.
+    * 2.79 - Added ``with_count`` in share snapshot list API to get total
+             count info.
+    * 2.80 - Added share backup APIs.
+    * 2.81 - Added API methods, endpoint /resource-locks.
+    * 2.82 - Added lock and restriction to share access rules.
+    * 2.83 - Added 'disabled_reason' field to services.
+    * 2.84 - Added mount_point_name to shares.
+    * 2.85 - Added backup_type field to share backups.
+    * 2.86 - Add ensure share API.
+    * 2.87 - Added Share export location metadata API
+    * 2.88 - Added support for update Share access rule.
+    * 2.89 - Added support for passing Share network subnet metadata updates
+             to driver.
+    * 2.90 - Added encryption key reference option to share create API.
+    * 2.91 - Added support for targeted restores via the share backup API
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.73"
+_MAX_API_VERSION = "2.91"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
@@ -256,7 +277,7 @@ class APIVersionRequest(utils.ComparableMixin):
 
     @experimental.setter
     def experimental(self, value):
-        if type(value) != bool:
+        if not isinstance(value, bool):
             msg = _('The experimental property must be a bool value.')
             raise exception.InvalidParameterValue(err=msg)
         self._experimental = value
@@ -264,7 +285,7 @@ class APIVersionRequest(utils.ComparableMixin):
     def matches_versioned_method(self, method):
         """Compares this version to that of a versioned method."""
 
-        if type(method) != versioned_method.VersionedMethod:
+        if not isinstance(method, versioned_method.VersionedMethod):
             msg = _('An API version request must be compared '
                     'to a VersionedMethod object.')
             raise exception.InvalidParameterValue(err=msg)
