@@ -203,7 +203,8 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description', 'limit', 'offset', 'is_soft_deleted')
+            'display_description', 'limit', 'offset', 'is_soft_deleted',
+            'mount_point_name')
 
     @wsgi.Controller.authorize
     def update(self, req, id, body):
@@ -256,7 +257,7 @@ class ShareMixin(object):
     def _create(self, req, body,
                 check_create_share_from_snapshot_support=False,
                 check_availability_zones_extra_spec=False,
-                scheduler_hints=None):
+                scheduler_hints=None, encryption_key_ref=None):
         """Creates a new share."""
         context = req.environ['manila.context']
 
@@ -412,11 +413,16 @@ class ShareMixin(object):
         # Only use in create share feature. Create share from snapshot
         # and create share with share group features not
         # need this check.
+        if share_type and share_type.get('extra_specs'):
+            dhss = (strutils.bool_from_string(
+                share_type.get('extra_specs').get(
+                    'driver_handles_share_servers')))
+        else:
+            dhss = False
+
         if (not share_network_id and not snapshot
                 and not share_group_id
-                and share_type and share_type.get('extra_specs')
-                and (strutils.bool_from_string(share_type.get('extra_specs').
-                     get('driver_handles_share_servers')))):
+                and dhss):
             msg = _('Share network must be set when the '
                     'driver_handles_share_servers is true.')
             raise exc.HTTPBadRequest(explanation=msg)
@@ -439,12 +445,27 @@ class ShareMixin(object):
                 payload = {'type': type_chosen, 'az': availability_zone}
                 raise exc.HTTPBadRequest(explanation=msg % payload)
 
+        if share_type and encryption_key_ref:
+            type_enc = share_type.get(
+                'extra_specs', {}).get('encryption_support')
+            if type_enc not in constants.SUPPORTED_ENCRYPTION_TYPES:
+                msg = _("Share type %(type)s extra-specs 'encryption_support' "
+                        "is missing valid value e.g. share, share_server.")
+                payload = {'type': share_type}
+                raise exc.HTTPBadRequest(explanation=msg % payload)
+            if not dhss:
+                msg = _("Share type %(type)s must set dhss=True for share "
+                        "encryption.")
+                payload = {'type': share_type}
+                raise exc.HTTPBadRequest(explanation=msg % payload)
+
         if share_type:
             kwargs['share_type'] = share_type
         if share_network_id:
             kwargs['share_network_id'] = share_network_id
 
         kwargs['scheduler_hints'] = scheduler_hints
+        kwargs['encryption_key_ref'] = encryption_key_ref
 
         if req.api_version_request >= api_version.APIVersionRequest("2.84"):
             kwargs['mount_point_name'] = share.pop('mount_point_name', None)
@@ -476,29 +497,52 @@ class ShareMixin(object):
         access['project_id'] = context.project_id
         access['user_id'] = context.user_id
 
-        def raise_lock_failed(access, lock_action):
+        def raise_lock_failed(resource_id, lock_action,
+                              resource_type='access rule'):
             word_mapping = {
                 constants.RESOURCE_ACTION_SHOW: 'visibility',
                 constants.RESOURCE_ACTION_DELETE: 'deletion'
             }
-            msg = _("Failed to lock the %(action)s of the access rule "
-                    "%(rule)s.") % {
+            msg = _("Failed to lock the %(action)s of the %(resource_type)s "
+                    "%(resource_id)s.") % {
                 'action': word_mapping[lock_action],
-                'rule': access['id']
+                'resource_id': resource_id,
+                'resource_type': resource_type
             }
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
-        deletion_lock = {}
+        access_deletion_lock = {}
+        share_deletion_lock = {}
 
         if lock_deletion:
             try:
-                deletion_lock = self.resource_locks_api.create(
+                access_deletion_lock = self.resource_locks_api.create(
                     context, resource_id=access['id'],
                     resource_type='access_rule',
                     resource_action=constants.RESOURCE_ACTION_DELETE,
                     resource=access, lock_reason=lock_reason)
             except Exception:
-                raise_lock_failed(access, constants.RESOURCE_ACTION_DELETE)
+                raise_lock_failed(
+                    access['id'], constants.RESOURCE_ACTION_DELETE
+                )
+            try:
+                share_lock_reason = (
+                    constants.SHARE_LOCKED_BY_ACCESS_LOCK_REASON % {
+                        'lock_id': access_deletion_lock['id']
+                    }
+                )
+                share_deletion_lock = self.resource_locks_api.create(
+                    context, resource_id=access['share_id'],
+                    resource_type='share',
+                    resource_action=constants.RESOURCE_ACTION_DELETE,
+                    lock_reason=share_lock_reason)
+            except Exception:
+                self.resource_locks_api.delete(
+                    context, access_deletion_lock['id'])
+                raise_lock_failed(
+                    access['share_id'], constants.RESOURCE_ACTION_DELETE,
+                    resource_type='share'
+                )
 
         if lock_visibility:
             try:
@@ -510,10 +554,13 @@ class ShareMixin(object):
             except Exception:
                 # If a deletion lock was placed and the visibility wasn't,
                 # we should rollback the deletion lock.
-                if deletion_lock:
+                if access_deletion_lock:
                     self.resource_locks_api.delete(
-                        context, deletion_lock['id'])
-                raise_lock_failed(access, constants.RESOURCE_ACTION_SHOW)
+                        context, access_deletion_lock['id'])
+                if share_deletion_lock:
+                    self.resource_locks_api.delete(
+                        context, share_deletion_lock['id'])
+                raise_lock_failed(access['id'], constants.RESOURCE_ACTION_SHOW)
 
     @wsgi.Controller.authorize('allow_access')
     def _allow_access(self, req, id, body, enable_ceph=False,
