@@ -17,6 +17,7 @@
 
 from http import client as http_client
 
+from oslo_utils import strutils
 import webob
 from webob import exc
 
@@ -56,7 +57,7 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
         try:
             self.share_api.delete_share_replica(context, resource, force=True)
         except exception.ReplicationException as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
 
     @wsgi.Controller.api_version(
         MIN_SUPPORTED_API_VERSION, PRE_GRADUATION_VERSION, experimental=True)
@@ -175,6 +176,11 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
                     "since it has been soft deleted.") % share_id
             raise exc.HTTPForbidden(explanation=msg)
 
+        if share_ref.get('encryption_key_ref'):
+            msg = _("Replica cannot be created for share '%s' "
+                    "since it is encrypted.") % share_id
+            raise exc.HTTPForbidden(explanation=msg)
+
         share_network_id = body.get('share_replica').get('share_network_id')
         if share_network_id:
             if req.api_version_request < api_version.APIVersionRequest("2.72"):
@@ -191,7 +197,7 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
                 common.check_share_network_is_active(share_network)
         except exception.ShareNetworkNotFound:
             msg = _("No share network exists with ID %s.")
-            raise exc.HTTPNotFound(explanation=msg % share_network_id)
+            raise exc.HTTPBadRequest(explanation=msg % share_network_id)
 
         try:
             new_replica = self.share_api.create_share_replica(
@@ -199,11 +205,11 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
                 share_network_id=share_network_id,
                 scheduler_hints=scheduler_hints)
         except exception.AvailabilityZoneNotFound as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
         except exception.ReplicationException as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
         except exception.ShareBusyException as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
 
         return self._view_builder.detail(req, new_replica)
 
@@ -230,7 +236,7 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
         try:
             self.share_api.delete_share_replica(context, replica)
         except exception.ReplicationException as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -241,14 +247,21 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
     def promote(self, req, id, body):
         return self._promote(req, id, body)
 
-    @wsgi.Controller.api_version(GRADUATION_VERSION)  # noqa
+    @wsgi.Controller.api_version(GRADUATION_VERSION, "2.74")  # noqa
+    @wsgi.response(202)
+    @wsgi.action('promote')
+    def promote(self, req, id, body): # pylint: disable=function-redefined  # noqa F811
+        return self._promote(req, id, body)
+
+    @wsgi.Controller.api_version("2.75")  # noqa
     @wsgi.response(202)
     @wsgi.action('promote')
     def promote(self, req, id, body):  # pylint: disable=function-redefined  # noqa F811
-        return self._promote(req, id, body)
+        return self._promote(req, id, body, allow_quiesce_wait_time=True)
 
     @wsgi.Controller.authorize('promote')
-    def _promote(self, req, id, body):
+    def _promote(self, req, id, body,
+                 allow_quiesce_wait_time=False):
         """Promote a replica to active state."""
         context = req.environ['manila.context']
 
@@ -268,10 +281,27 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
         if replica_state == constants.REPLICA_STATE_ACTIVE:
             return webob.Response(status_int=http_client.OK)
 
+        quiesce_wait_time = None
+        if allow_quiesce_wait_time:
+            # NOTE(carloss): there is a chance that we receive
+            # {'promote': null}, so we need to prevent that
+            promote_data = body.get('promote', {})
+            promote_data = {} if promote_data is None else promote_data
+            wait_time = promote_data.get('quiesce_wait_time')
+            if wait_time:
+                if not strutils.is_int_like(wait_time) or int(wait_time) <= 0:
+                    msg = _("quiesce_wait_time must be an integer and "
+                            "greater than 0.")
+                    raise exc.HTTPBadRequest(explanation=msg)
+                else:
+                    quiesce_wait_time = int(wait_time)
+
         try:
-            replica = self.share_api.promote_share_replica(context, replica)
+            replica = self.share_api.promote_share_replica(
+                context, replica,
+                quiesce_wait_time=quiesce_wait_time)
         except exception.ReplicationException as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
         except exception.AdminRequired as e:
             raise exc.HTTPForbidden(explanation=e.message)
 
@@ -355,7 +385,7 @@ class ShareReplicationController(wsgi.Controller, wsgi.AdminActionsMixin):
         try:
             self.share_api.update_share_replica(context, replica)
         except exception.InvalidHost as e:
-            raise exc.HTTPBadRequest(explanation=e.message)
+            raise exc.HTTPBadRequest(explanation=e.msg)
 
 
 def create_resource():
