@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Copyright (c) 2011 X.commerce, a business unit of eBay Inc.
 # Copyright 2010 United States Government as represented by the
@@ -55,9 +55,11 @@
 
 import os
 import sys
+import yaml
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_serialization import jsonutils
 
 from manila.common import config  # Need to register global_opts  # noqa
 from manila import context
@@ -69,6 +71,7 @@ from manila import version
 
 CONF = cfg.CONF
 
+ALLOWED_OUTPUT_FORMATS = ['table', 'json', 'yaml']
 HOST_UPDATE_HELP_MSG = ("A fully qualified host string is of the format "
                         "'HostA@BackendB#PoolC'. Provide only the host name "
                         "(ex: 'HostA') to update the hostname part of "
@@ -78,6 +81,13 @@ HOST_UPDATE_HELP_MSG = ("A fully qualified host string is of the format "
 HOST_UPDATE_CURRENT_HOST_HELP = ("Current share host name. %s" %
                                  HOST_UPDATE_HELP_MSG)
 HOST_UPDATE_NEW_HOST_HELP = "New share host name. %s" % HOST_UPDATE_HELP_MSG
+LIST_OUTPUT_FORMAT_HELP = ("Format to be used to print the output (table, "
+                           "json, yaml). Defaults to 'table'")
+SHARE_SERVERS_UPDATE_HELP = ("List of share servers to be updated, separated "
+                             "by commas.")
+SHARE_SERVERS_UPDATE_CAPABILITIES_HELP = (
+    "List of share server capabilities to be updated, separated by commas.")
+SHARE_DELETE_HELP = ("Share ID to be deleted.")
 
 
 # Decorators for actions
@@ -88,6 +98,37 @@ def args(*args, **kwargs):
     return _decorator
 
 
+class ListCommand(object):
+
+    def list_json(self, resource_name, resource_list):
+        resource_list = {resource_name: resource_list}
+        object_list = jsonutils.dumps(resource_list, indent=4)
+        print(object_list)
+
+    def list_yaml(self, resource_name, resource_list):
+        resource_list = {resource_name: resource_list}
+        data_yaml = yaml.dump(resource_list)
+        print(data_yaml)
+
+    def list_table(self, resource_name, resource_list):
+        print_format = "{0:<16} {1:<36} {2:<16} {3:<10} {4:<5} {5:<10}"
+        print(print_format.format(
+            *[k.capitalize().replace(
+                '_', ' ') for k in resource_list[0].keys()]))
+        for resource in resource_list:
+            # Print is not transforming into a string, so let's ensure it
+            # happens
+            resource['updated_at'] = str(resource['updated_at'])
+            print(print_format.format(*resource.values()))
+
+    def _check_format_output(self, format_output):
+        if format_output not in ALLOWED_OUTPUT_FORMATS:
+            print('Invalid output format specified. Defaulting to table.')
+            return 'table'
+        else:
+            return format_output
+
+
 class ShellCommands(object):
     def bpython(self):
         """Runs a bpython shell.
@@ -314,35 +355,35 @@ class GetLogCommands(object):
             print("No manila entries in syslog!")
 
 
-class ServiceCommands(object):
+class ServiceCommands(ListCommand):
     """Methods for managing services."""
-    def list(self):
+
+    @args('--format_output', required=False, default='table',
+          help=LIST_OUTPUT_FORMAT_HELP)
+    def list(self, format_output):
         """Show a list of all manila services."""
         ctxt = context.get_admin_context()
         services = db.service_get_all(ctxt)
-        print_format = "%-16s %-36s %-16s %-10s %-5s %-10s"
-        print(print_format % (
-            _('Binary'),
-            _('Host'),
-            _('Zone'),
-            _('Status'),
-            _('State'),
-            _('Updated At'))
-        )
-        for svc in services:
-            alive = utils.service_is_up(svc)
-            art = ":-)" if alive else "XXX"
+        format_output = self._check_format_output(format_output)
+
+        services_list = []
+        for service in services:
+            alive = utils.service_is_up(service)
+            state = ":-)" if alive else "XXX"
             status = 'enabled'
-            if svc['disabled']:
+            if service['disabled']:
                 status = 'disabled'
-            print(print_format % (
-                svc['binary'],
-                svc['host'].partition('.')[0],
-                svc['availability_zone']['name'],
-                status,
-                art,
-                svc['updated_at'],
-            ))
+            services_list.append({
+                'binary': service['binary'],
+                'host': service['host'].partition('.')[0],
+                'zone': service['availability_zone']['name'],
+                'status': status,
+                'state': state,
+                'updated_at': str(service['updated_at']),
+            })
+
+        method_list_name = f'list_{format_output}'
+        getattr(self, method_list_name)('services', services_list)
 
     def cleanup(self):
         """Remove manila services reporting as 'down'."""
@@ -398,6 +439,67 @@ class ShareCommands(object):
         }
         print(msg % msg_args)
 
+    @args('--share_id', required=True, help=SHARE_DELETE_HELP)
+    def delete(self, share_id):
+        """Delete manila share from the database.
+
+           This command is useful after a share's manager service
+           has been decommissioned.
+        """
+        ctxt = context.get_admin_context()
+        share = db.share_get(ctxt, share_id)
+
+        active_replicas = []
+        # We delete "active" replicas at the end
+        for share_instance in share['instances']:
+            if share_instance['replica_state'] == "active":
+                active_replicas.append(share_instance)
+            else:
+                db.share_instance_delete(ctxt, share_instance['id'])
+        for share_instance in active_replicas:
+            db.share_instance_delete(ctxt, share_instance['id'])
+            print("Deleted share instance %s" % share_instance['id'])
+
+        # finally, clean up the share
+        print("Deleted share %s" % share_id)
+
+
+class ShareServerCommands(object):
+    @args('--share_servers', required=True,
+          help=SHARE_SERVERS_UPDATE_HELP)
+    @args('--capabilities', required=True,
+          help=SHARE_SERVERS_UPDATE_CAPABILITIES_HELP)
+    @args('--value', required=False, type=bool, default=False,
+          help="If those capabilities will be enabled (True) or disabled "
+               "(False)")
+    def update_share_server_capabilities(self, share_servers, capabilities,
+                                         value=False):
+        """Update the share server capabilities.
+
+           This method receives a list of share servers and capabilities
+           in order to have it updated with the value specified. If the value
+           was not specified the default is False.
+        """
+        share_servers = [server.strip() for server in share_servers.split(",")]
+        capabilities = [cap.strip() for cap in capabilities.split(",")]
+        supported_capabilities = ['security_service_update_support',
+                                  'network_allocation_update_support']
+
+        values = dict()
+        for capability in capabilities:
+            if capability not in supported_capabilities:
+                print("One or more capabilities are invalid for this "
+                      "operation. The supported capability(ies) is(are) %s."
+                      % supported_capabilities)
+                sys.exit(1)
+            values[capability] = value
+
+        ctxt = context.get_admin_context()
+        db.share_servers_update(ctxt, share_servers, values)
+        print("The capability(ies) %s of the following share server(s)"
+              " %s was(were) updated to %s." %
+              (capabilities, share_servers, value))
+
 
 CATEGORIES = {
     'config': ConfigCommands,
@@ -406,6 +508,7 @@ CATEGORIES = {
     'logs': GetLogCommands,
     'service': ServiceCommands,
     'share': ShareCommands,
+    'share_server': ShareServerCommands,
     'shell': ShellCommands,
     'version': VersionCommands
 }
