@@ -40,7 +40,7 @@ def upgrade():
 
         share_types = sql.Table('share_types', meta, is_public.copy())
         # pylint: disable=no-value-for-parameter
-        share_types.update().values(is_public=True).execute()
+        op.execute(share_types.update().values(is_public=True))
     except Exception:
         LOG.error("Column |%s| not created!", repr(is_public))
         raise
@@ -59,6 +59,7 @@ def upgrade():
             sql.UniqueConstraint('share_type_id', 'project_id', 'deleted',
                                  name="stp_project_id_uc"),
             mysql_engine='InnoDB',
+            mysql_charset='utf8'
         )
     except Exception:
         LOG.error("Table |%s| not created!", 'share_type_projects')
