@@ -199,6 +199,10 @@ class InvalidCapacity(Invalid):
     message = _("Invalid capacity: %(name)s = %(value)s.")
 
 
+class ValidationError(Invalid):
+    message = "%(detail)s"
+
+
 class NotFound(ManilaException):
     message = _("Resource could not be found.")
     code = 404
@@ -496,6 +500,11 @@ class ShareReplicaSizeExceedsAvailableQuota(QuotaError):
         "gigabytes quota.")
 
 
+class EncryptionKeysLimitExceeded(QuotaError):
+    message = _(
+        "Maximum number of allowed encryption keys is exceeded.")
+
+
 class GlusterfsException(ManilaException):
     message = _("Unknown Gluster exception.")
 
@@ -534,6 +543,10 @@ class PortLimitExceeded(QuotaError):
     message = _("Maximum number of ports exceeded.")
 
 
+class IpAddressGenerationFailureClient(ManilaException):
+    message = _("No free IP addresses available in neutron subnet.")
+
+
 class ShareAccessExists(ManilaException):
     message = _("Share access %(access_type)s:%(access)s exists.")
 
@@ -574,6 +587,14 @@ class ShareBackendException(ManilaException):
     message = _("Share backend error: %(msg)s.")
 
 
+class OperationNotSupportedByDriverMode(ManilaException):
+    message = _("The share driver mode does not support this operation.")
+
+
+class RequirementMissing(ManilaException):
+    message = _("Requirement %(req)s is not installed.")
+
+
 class ExportLocationNotFound(NotFound):
     message = _("Export location %(uuid)s could not be found.")
 
@@ -771,6 +792,15 @@ class ShareTypeUpdateFailed(ManilaException):
     message = _("Cannot update share_type %(id)s.")
 
 
+class ManilaBarbicanACLError(ManilaException):
+    message = _("Failed while communicating to Barbican. "
+                "Please check the provided credentials .")
+
+
+class ManilaBarbicanAppCredsError(ManilaException):
+    message = _("Error occured while dealing with barbican for App Creds.")
+
+
 class ShareGroupTypeCreateFailed(ManilaException):
     message = _("Cannot create share group type with "
                 "name %(name)s and specs %(group_specs)s.")
@@ -1182,3 +1212,20 @@ class ShareBackupSizeExceedsAvailableQuota(QuotaError):
 class NetappActiveIQWeigherRequiredParameter(ManilaException):
     message = _("%(config)s configuration of the NetAppActiveIQ weigher "
                 "must be set.")
+
+
+# Vastdata Storage driver
+class VastApiException(ManilaException):
+    message = _("Rest api error: %(reason)s.")
+
+
+class VastApiRetry(ManilaException):
+    message = _("Rest api retry: %(reason)s.")
+
+
+class VastShareNotFound(ShareBackendException):
+    message = _("Share %(name)s could not be found.")
+
+
+class VastDriverException(ShareBackendException):
+    message = _("Vast driver error: %(reason)s.")
