@@ -26,6 +26,7 @@ from manila.i18n import _
 from manila import network
 from manila.network.neutron import api as neutron_api
 from manila.network.neutron import constants as neutron_constants
+from manila.share import utils as share_utils
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -123,14 +124,17 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
     def include_network_info(self, share_network_subnet):
         """Includes share-network-subnet with plugin specific data."""
-        self._store_neutron_net_info(None, share_network_subnet, save_db=False)
+        self._store_and_get_neutron_net_info(None,
+                                             share_network_subnet,
+                                             save_db=False)
 
-    def _store_neutron_net_info(self, context, share_network_subnet,
-                                save_db=True):
-        self._save_neutron_network_data(context, share_network_subnet,
-                                        save_db=save_db)
+    def _store_and_get_neutron_net_info(self, context, share_network_subnet,
+                                        save_db=True):
+        is_external_network = self._save_neutron_network_data(
+            context, share_network_subnet, save_db=save_db)
         self._save_neutron_subnet_data(context, share_network_subnet,
                                        save_db=save_db)
+        return is_external_network
 
     def allocate_network(self, context, share_server, share_network=None,
                          share_network_subnet=None, **kwargs):
@@ -156,16 +160,23 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
         self._verify_share_network(share_server['id'], share_network)
         self._verify_share_network_subnet(share_server['id'],
                                           share_network_subnet)
-        self._store_neutron_net_info(context, share_network_subnet)
+        is_external_network = self._store_and_get_neutron_net_info(
+            context, share_network_subnet)
 
         allocation_count = kwargs.get('count', 1)
         device_owner = kwargs.get('device_owner', 'share')
 
         ports = []
-        for __ in range(0, allocation_count):
-            ports.append(self._create_port(
-                         context, share_server, share_network,
-                         share_network_subnet, device_owner))
+        for current_count in range(0, allocation_count):
+            ports.append(
+                self._create_port(context,
+                                  share_server,
+                                  share_network,
+                                  share_network_subnet,
+                                  device_owner,
+                                  current_count,
+                                  is_external_network=is_external_network),
+            )
 
         return ports
 
@@ -175,7 +186,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         self._verify_share_network_subnet(share_server['id'],
                                           share_network_subnet)
-        self._store_neutron_net_info(context, share_network_subnet)
+        self._store_and_get_neutron_net_info(context, share_network_subnet)
 
         # We begin matching the allocations to known neutron ports and
         # finally return the non-consumed allocations
@@ -295,7 +306,8 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
                                                             ip_version}
         raise exception.NetworkBadConfigurationException(reason=msg)
 
-    def deallocate_network(self, context, share_server_id):
+    def deallocate_network(self, context, share_server_id,
+                           share_network=None, share_network_subnet=None):
         """Deallocate neutron network resources for the given share server.
 
         Delete previously allocated neutron ports, delete manila db
@@ -303,6 +315,8 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         :param context: RequestContext object
         :param share_server_id: id of share server
+        :param share_network: share network data
+        :param share_network_subnet: share network subnet data
         :rtype: None
         """
         ports = self.db.network_allocations_get_for_share_server(
@@ -311,23 +325,59 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
         for port in ports:
             self._delete_port(context, port)
 
+        # It may be possible that there are ports existing without a
+        # corresponding manila network allocation entry in the manila db,
+        # because port create request may have been successfully sent to
+        # neutron, but the response, the created port could not be stored
+        # in manila due to unreachable db
+        if share_network_subnet:
+            ports = []
+            try:
+                ports = self.neutron_api.list_ports(
+                    network_id=share_network_subnet['neutron_net_id'],
+                    device_owner='manila:share',
+                    device_id=share_server_id)
+            except exception.NetworkException:
+                LOG.warning("Failed to list ports using neutron API during "
+                            "deallocate_network.")
+            for port in ports:
+                LOG.debug(f"Deleting orphaned port {port['id']} belonging to "
+                          f"share server {share_server_id} in neutron "
+                          f"network {share_network_subnet['neutron_net_id']}")
+                self._delete_port(context, port, ignore_db=True)
+
     def _get_port_create_args(self, share_server, share_network_subnet,
-                              device_owner):
+                              device_owner, count=0,
+                              is_external_network=False):
         return {
             "network_id": share_network_subnet['neutron_net_id'],
             "subnet_id": share_network_subnet['neutron_subnet_id'],
             "device_owner": 'manila:' + device_owner,
             "device_id": share_server.get('id'),
+            "name": share_server.get('id') + '_' + str(count),
+            # NOTE (gouthamr): we create disabled ports with external networks
+            # since the actual ports are not managed by neutron. The ports
+            # neutron creates merely assist in IPAM.
+            "admin_state_up": not is_external_network,
         }
 
     def _create_port(self, context, share_server, share_network,
-                     share_network_subnet, device_owner):
+                     share_network_subnet, device_owner, count=0,
+                     is_external_network=False):
         create_args = self._get_port_create_args(
-            share_server, share_network_subnet, device_owner)
+            share_server, share_network_subnet, device_owner, count,
+            is_external_network=is_external_network)
 
         port = self.neutron_api.create_port(
             share_network['project_id'], **create_args)
 
+        if is_external_network:
+            msg = (
+                f"Port '{port['id']}' is disabled to prevent improper "
+                f"routing on an external network."
+            )
+            LOG.info(msg)
+
         ip_address = self._get_matched_ip_address(
             port['fixed_ips'], share_network_subnet['ip_version'])
         port_dict = {
@@ -352,15 +402,17 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
 
         return self.db.network_allocation_create(context, port_dict)
 
-    def _delete_port(self, context, port):
+    def _delete_port(self, context, port, ignore_db=False):
         try:
             self.neutron_api.delete_port(port['id'])
         except exception.NetworkException:
-            self.db.network_allocation_update(
-                context, port['id'], {'status': constants.STATUS_ERROR})
+            if not ignore_db:
+                self.db.network_allocation_update(
+                    context, port['id'], {'status': constants.STATUS_ERROR})
             raise
         else:
-            self.db.network_allocation_delete(context, port['id'])
+            if not ignore_db:
+                self.db.network_allocation_delete(context, port['id'])
 
     def _has_provider_network_extension(self):
         extensions = self.neutron_api.list_extensions()
@@ -378,6 +430,7 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             share_network_subnet['neutron_net_id'])
         segmentation_id = None
         network_type = None
+        is_external_network = net_info.get('router:external', False)
 
         if self._is_neutron_multi_segment(share_network_subnet, net_info):
             # we have a multi segment network and need to identify the
@@ -412,6 +465,8 @@ class NeutronNetworkPlugin(network.NetworkBaseAPI):
             self.db.share_network_subnet_update(
                 context, share_network_subnet['id'], provider_nw_dict)
 
+        return is_external_network
+
     def _save_neutron_subnet_data(self, context, share_network_subnet,
                                   save_db=True):
         subnet_info = self.neutron_api.get_subnet(
@@ -577,10 +632,13 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
         raise exception.NetworkBindException(msg)
 
     def _get_port_create_args(self, share_server, share_network_subnet,
-                              device_owner):
+                              device_owner, count=0,
+                              is_external_network=False):
         arguments = super(
             NeutronBindNetworkPlugin, self)._get_port_create_args(
-            share_server, share_network_subnet, device_owner)
+            share_server, share_network_subnet, device_owner, count,
+            is_external_network=is_external_network
+        )
         arguments['host_id'] = self.config.neutron_host_id
         arguments['binding:vnic_type'] = self.config.neutron_vnic_type
         if self.binding_profiles:
@@ -665,6 +723,70 @@ class NeutronBindNetworkPlugin(NeutronNetworkPlugin):
                         context, port['id'], port_info)
         return ports
 
+    @utils.retry(retry_param=exception.NetworkException, retries=20)
+    def _wait_for_network_segment(self, share_server, host):
+        network_id = share_server['share_network_subnet']['neutron_net_id']
+        network = self.neutron_api.get_network(network_id)
+        for segment in network['segments']:
+            if segment['provider:physical_network'] == (
+                    self.config.neutron_physical_net_name):
+                return segment['provider:segmentation_id']
+        msg = _('Network segment not found on host %s') % host
+        raise exception.NetworkException(msg)
+
+    def extend_network_allocations(self, context, share_server):
+        """Extend network to target host.
+
+        This will create port bindings on target host without activating them.
+        If network segment does not exist on target host, it will be created.
+
+        :return: list of port bindings with new segmentation id on target host
+        """
+        vnic_type = self.config.neutron_vnic_type
+        host_id = self.config.neutron_host_id
+
+        active_port_bindings = (
+            self.db.network_allocations_get_for_share_server(
+                context, share_server['id'], label='user'))
+        if len(active_port_bindings) == 0:
+            raise exception.NetworkException(
+                'Can not extend network with no active bindings')
+
+        # Create port binding on destination backend. It's safe to call neutron
+        # api bind_port_to_host if the port is already bound to destination
+        # host.
+        for port in active_port_bindings:
+            self.neutron_api.bind_port_to_host(port['id'], host_id,
+                                               vnic_type)
+
+        # Wait for network segment to be created on destination host.
+        vlan = self._wait_for_network_segment(share_server, host_id)
+        for port in active_port_bindings:
+            port['segmentation_id'] = vlan
+
+        return active_port_bindings
+
+    def delete_extended_allocations(self, context, share_server):
+        host_id = self.config.neutron_host_id
+        ports = self.db.network_allocations_get_for_share_server(
+            context, share_server['id'], label='user')
+        for port in ports:
+            try:
+                self.neutron_api.delete_port_binding(port['id'], host_id)
+            except exception.NetworkException as e:
+                msg = 'Failed to delete port binding on port %{port}s: %{err}s'
+                LOG.warning(msg, {'port': port['id'], 'err': e})
+
+    def cutover_network_allocations(self, context, src_share_server):
+        src_host = share_utils.extract_host(src_share_server['host'], 'host')
+        dest_host = self.config.neutron_host_id
+        ports = self.db.network_allocations_get_for_share_server(
+            context, src_share_server['id'], label='user')
+        for port in ports:
+            self.neutron_api.activate_port_binding(port['id'], dest_host)
+            self.neutron_api.delete_port_binding(port['id'], src_host)
+        return ports
+
 
 class NeutronBindSingleNetworkPlugin(NeutronSingleNetworkPlugin,
                                      NeutronBindNetworkPlugin):
