@@ -16,7 +16,6 @@
 import netaddr
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from manila.common import constants
 from manila import exception
@@ -27,13 +26,11 @@ from manila import utils
 standalone_network_plugin_opts = [
     cfg.StrOpt(
         'standalone_network_plugin_gateway',
-        help="Gateway address that should be used. Required.",
-        deprecated_group='DEFAULT'),
+        help="Gateway address that should be used. Required."),
     cfg.StrOpt(
         'standalone_network_plugin_mask',
         help="Network mask that will be used. Can be either decimal "
-             "like '24' or binary like '255.255.255.0'. Required.",
-        deprecated_group='DEFAULT'),
+             "like '24' or binary like '255.255.255.0'. Required."),
     cfg.StrOpt(
         'standalone_network_plugin_network_type',
         help="Network type, such as 'flat', 'vlan', 'vxlan' or 'gre'. "
@@ -41,15 +38,13 @@ standalone_network_plugin_opts = [
              "It will be assigned to share-network and share drivers will be "
              "able to use this for network interfaces within provisioned "
              "share servers. Optional.",
-        choices=['flat', 'vlan', 'vxlan', 'gre'],
-        deprecated_group='DEFAULT'),
+        choices=['flat', 'vlan', 'vxlan', 'gre']),
     cfg.IntOpt(
         'standalone_network_plugin_segmentation_id',
         help="Set it if network has segmentation (VLAN, VXLAN, etc...). "
              "It will be assigned to share-network and share drivers will be "
              "able to use this for network interfaces within provisioned "
-             "share servers. Optional. Example: 1001",
-        deprecated_group='DEFAULT'),
+             "share servers. Optional. Example: 1001"),
     cfg.ListOpt(
         'standalone_network_plugin_allowed_ip_ranges',
         help="Can be IP address, range of IP addresses or list of addresses "
@@ -57,14 +52,12 @@ standalone_network_plugin_opts = [
              "to be used. If empty, then will be assumed that all host "
              "addresses from network can be used. Optional. "
              "Examples: 10.0.0.10 or 10.0.0.10-10.0.0.20 or "
-             "10.0.0.10-10.0.0.20,10.0.0.30-10.0.0.40,10.0.0.50",
-        deprecated_group='DEFAULT'),
+             "10.0.0.10-10.0.0.20,10.0.0.30-10.0.0.40,10.0.0.50"),
     cfg.IntOpt(
         'standalone_network_plugin_mtu',
         default=1500,
         help="Maximum Transmission Unit (MTU) value of the network. Default "
-             "value is 1500.",
-        deprecated_group='DEFAULT'),
+             "value is 1500."),
 ]
 
 CONF = cfg.CONF
@@ -107,7 +100,7 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
             dict(
                 config_group=self.config_group_name,
                 ip_version=self.ip_version,
-                net=six.text_type(self.net),
+                net=str(self.net),
                 gateway=self.gateway,
                 network_type=self.network_type,
                 segmentation_id=self.segmentation_id,
@@ -152,18 +145,18 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
         self.net = self._get_network()
         self.allowed_cidrs = self._get_list_of_allowed_addresses()
         self.reserved_addresses = (
-            six.text_type(self.net.network),
+            str(self.net.network),
             self.gateway,
-            six.text_type(self.net.broadcast))
+            str(self.net.broadcast))
         self.mtu = self.configuration.standalone_network_plugin_mtu
 
     def _get_network(self):
         """Returns IPNetwork object calculated from gateway and netmask."""
-        if not isinstance(self.gateway, six.string_types):
+        if not isinstance(self.gateway, str):
             raise exception.NetworkBadConfigurationException(
                 _("Configuration option 'standalone_network_plugin_gateway' "
                   "is required and has improper value '%s'.") % self.gateway)
-        if not isinstance(self.mask, six.string_types):
+        if not isinstance(self.mask, str):
             raise exception.NetworkBadConfigurationException(
                 _("Configuration option 'standalone_network_plugin_mask' is "
                   "required and has improper value '%s'.") % self.mask)
@@ -213,8 +206,8 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
 
                 if range_instance not in self.net:
                     data = dict(
-                        range=six.text_type(range_instance),
-                        net=six.text_type(self.net),
+                        range=str(range_instance),
+                        net=str(self.net),
                         gateway=self.gateway,
                         netmask=self.net.netmask)
                     msg = _("One of provided allowed IP ranges ('%(range)s') "
@@ -225,14 +218,14 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
                         reason=msg)
 
                 cidrs.extend(
-                    six.text_type(cidr) for cidr in range_instance.cidrs())
+                    str(cidr) for cidr in range_instance.cidrs())
         else:
             if self.net.version != self.ip_version:
                 msg = _("Configured invalid IP version '%(conf_v)s', network "
                         "has version ""'%(net_v)s'") % dict(
                             conf_v=self.ip_version, net_v=self.net.version)
                 raise exception.NetworkBadConfigurationException(reason=msg)
-            cidrs.append(six.text_type(self.net))
+            cidrs.append(str(self.net))
 
         return cidrs
 
@@ -247,7 +240,7 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
             return ips
         iterator = netaddr.iter_unique_ips(*self.allowed_cidrs)
         for ip in iterator:
-            ip = six.text_type(ip)
+            ip = str(ip)
             if (ip in self.reserved_addresses or
                     self.db.network_allocations_get_by_ip_address(context,
                                                                   ip)):
@@ -264,24 +257,29 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
                     'available': len(ips)}
         raise exception.NetworkBadConfigurationException(reason=msg)
 
-    def _save_network_info(self, context, share_network):
-        """Update share-network with plugin specific data."""
+    def include_network_info(self, share_network_subnet):
+        """Includes share-network-subnet with plugin specific data."""
+        self._save_network_info(None, share_network_subnet, save_db=False)
+
+    def _save_network_info(self, context, share_network_subnet, save_db=True):
+        """Update share-network-subnet with plugin specific data."""
         data = {
             'network_type': self.network_type,
             'segmentation_id': self.segmentation_id,
-            'cidr': six.text_type(self.net.cidr),
-            'gateway': six.text_type(self.gateway),
+            'cidr': str(self.net.cidr),
+            'gateway': str(self.gateway),
             'ip_version': self.ip_version,
             'mtu': self.mtu,
         }
-        share_network.update(data)
-        if self.label != 'admin':
-            self.db.share_network_update(context, share_network['id'], data)
+        share_network_subnet.update(data)
+        if self.label != 'admin' and save_db:
+            self.db.share_network_subnet_update(
+                context, share_network_subnet['id'], data)
 
     @utils.synchronized(
         "allocate_network_for_standalone_network_plugin", external=True)
     def allocate_network(self, context, share_server, share_network=None,
-                         **kwargs):
+                         share_network_subnet=None, **kwargs):
         """Allocate network resources using one dedicated network.
 
         This one has interprocess lock to avoid concurrency in creation of
@@ -289,10 +287,11 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
         """
         allocation_count = kwargs.get('count', 1)
         if self.label != 'admin':
-            self._verify_share_network(share_server['id'], share_network)
+            self._verify_share_network(share_server['id'],
+                                       share_network_subnet)
         else:
-            share_network = share_network or {}
-        self._save_network_info(context, share_network)
+            share_network_subnet = share_network_subnet or {}
+        self._save_network_info(context, share_network_subnet)
         allocations = []
         ip_addresses = self._get_available_ips(context, allocation_count)
         for ip_address in ip_addresses:
@@ -301,20 +300,72 @@ class StandaloneNetworkPlugin(network.NetworkBaseAPI):
                 'ip_address': ip_address,
                 'status': constants.STATUS_ACTIVE,
                 'label': self.label,
-                'network_type': share_network['network_type'],
-                'segmentation_id': share_network['segmentation_id'],
-                'cidr': share_network['cidr'],
-                'gateway': share_network['gateway'],
-                'ip_version': share_network['ip_version'],
-                'mtu': share_network['mtu'],
+                'network_type': share_network_subnet['network_type'],
+                'segmentation_id': share_network_subnet['segmentation_id'],
+                'cidr': share_network_subnet['cidr'],
+                'gateway': share_network_subnet['gateway'],
+                'ip_version': share_network_subnet['ip_version'],
+                'mtu': share_network_subnet['mtu'],
             }
+            if self.label != 'admin':
+                data['share_network_subnet_id'] = (
+                    share_network_subnet['id'])
             allocations.append(
                 self.db.network_allocation_create(context, data))
         return allocations
 
-    def deallocate_network(self, context, share_server_id):
+    def deallocate_network(self, context, share_server_id,
+                           share_network=None, share_network_subnet=None):
         """Deallocate network resources for share server."""
         allocations = self.db.network_allocations_get_for_share_server(
             context, share_server_id)
         for allocation in allocations:
             self.db.network_allocation_delete(context, allocation['id'])
+
+    def unmanage_network_allocations(self, context, share_server_id):
+        self.deallocate_network(context, share_server_id)
+
+    def manage_network_allocations(self, context, allocations, share_server,
+                                   share_network=None,
+                                   share_network_subnet=None):
+        if self.label != 'admin':
+            self._verify_share_network_subnet(share_server['id'],
+                                              share_network_subnet)
+        else:
+            share_network_subnet = share_network_subnet or {}
+        self._save_network_info(context, share_network_subnet)
+
+        # We begin matching the allocations to known neutron ports and
+        # finally return the non-consumed allocations
+        remaining_allocations = list(allocations)
+
+        ips = [netaddr.IPAddress(allocation) for allocation
+               in remaining_allocations]
+        cidrs = [netaddr.IPNetwork(cidr) for cidr in self.allowed_cidrs]
+        selected_allocations = []
+
+        for ip in ips:
+            if any(ip in cidr for cidr in cidrs):
+                allocation = str(ip)
+                selected_allocations.append(allocation)
+
+        for allocation in selected_allocations:
+            data = {
+                'share_server_id': share_server['id'],
+                'ip_address': allocation,
+                'status': constants.STATUS_ACTIVE,
+                'label': self.label,
+                'network_type': share_network_subnet['network_type'],
+                'segmentation_id': share_network_subnet['segmentation_id'],
+                'cidr': share_network_subnet['cidr'],
+                'gateway': share_network_subnet['gateway'],
+                'ip_version': share_network_subnet['ip_version'],
+                'mtu': share_network_subnet['mtu'],
+            }
+            if self.label != 'admin':
+                data['share_network_subnet_id'] = (
+                    share_network_subnet['id'])
+            self.db.network_allocation_create(context, data)
+            remaining_allocations.remove(allocation)
+
+        return remaining_allocations
