@@ -24,7 +24,6 @@ import random
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging as messaging
-from oslo_service import loopingcall
 from oslo_service import service
 from oslo_service import wsgi
 from oslo_utils import importutils
@@ -34,14 +33,23 @@ from manila import coordination
 from manila import db
 from manila import exception
 from manila import rpc
+from manila import utils
 from manila import version
 
+osprofiler_initializer = importutils.try_import('osprofiler.initializer')
+profiler = importutils.try_import('osprofiler.profiler')
+profiler_opts = importutils.try_import('osprofiler.opts')
+
 LOG = log.getLogger(__name__)
 
 service_opts = [
     cfg.IntOpt('report_interval',
                default=10,
                help='Seconds between nodes reporting state to datastore.'),
+    cfg.IntOpt('cleanup_interval',
+               min=300,
+               default=1800,
+               help='Seconds between cleaning up the stopped nodes.'),
     cfg.IntOpt('periodic_interval',
                default=60,
                help='Seconds between running periodic tasks.'),
@@ -68,6 +76,26 @@ service_opts = [
 
 CONF = cfg.CONF
 CONF.register_opts(service_opts)
+if profiler_opts:
+    profiler_opts.set_defaults(CONF)
+
+
+def setup_profiler(binary, host):
+    if (osprofiler_initializer is None or
+            profiler is None or
+            profiler_opts is None):
+        LOG.debug('osprofiler is not present')
+        return
+
+    if CONF.profiler.enabled:
+        osprofiler_initializer.init_from_conf(
+            conf=CONF,
+            context=context.get_admin_context().to_dict(),
+            project="manila",
+            service=binary,
+            host=host
+        )
+        LOG.warning("OSProfiler is enabled.")
 
 
 class Service(service.Service):
@@ -89,35 +117,45 @@ class Service(service.Service):
         self.topic = topic
         self.manager_class_name = manager
         manager_class = importutils.import_class(self.manager_class_name)
+        if CONF.profiler.enabled and profiler is not None:
+            manager_class = profiler.trace_cls("rpc")(manager_class)
+
+        self.service = None
         self.manager = manager_class(host=self.host,
                                      service_name=service_name,
                                      *args, **kwargs)
         self.availability_zone = self.manager.availability_zone
         self.report_interval = report_interval
+        self.cleanup_interval = CONF.cleanup_interval
         self.periodic_interval = periodic_interval
         self.periodic_fuzzy_delay = periodic_fuzzy_delay
         self.saved_args, self.saved_kwargs = args, kwargs
-        self.timers = []
         self.coordinator = coordination
 
+        self.rpcserver = None
+
     def start(self):
         version_string = version.version_string()
         LOG.info('Starting %(topic)s node (version %(version_string)s)',
                  {'topic': self.topic, 'version_string': version_string})
         self.model_disconnected = False
         ctxt = context.get_admin_context()
-
-        if self.coordinator:
-            coordination.LOCK_COORDINATOR.start()
+        setup_profiler(self.binary, self.host)
 
         try:
             service_ref = db.service_get_by_args(ctxt,
                                                  self.host,
                                                  self.binary)
             self.service_id = service_ref['id']
+            db.service_update(ctxt, self.service_id, {'state': 'down'})
         except exception.NotFound:
             self._create_service_ref(ctxt)
 
+        self.manager.init_host(service_id=self.service_id)
+
+        if self.coordinator:
+            coordination.LOCK_COORDINATOR.start()
+
         LOG.debug("Creating RPC server for service %s.", self.topic)
 
         target = messaging.Target(topic=self.topic, server=self.host)
@@ -126,12 +164,14 @@ class Service(service.Service):
         self.rpcserver = rpc.get_server(target, endpoints)
         self.rpcserver.start()
 
-        self.manager.init_host()
+        self.manager.init_host_with_rpc()
+
         if self.report_interval:
-            pulse = loopingcall.FixedIntervalLoopingCall(self.report_state)
-            pulse.start(interval=self.report_interval,
-                        initial_delay=self.report_interval)
-            self.timers.append(pulse)
+            self.tg.add_timer(self.report_interval, self.report_state,
+                              initial_delay=self.report_interval)
+
+        self.tg.add_timer(self.cleanup_interval, self.cleanup_services,
+                          initial_delay=self.cleanup_interval)
 
         if self.periodic_interval:
             if self.periodic_fuzzy_delay:
@@ -139,17 +179,15 @@ class Service(service.Service):
             else:
                 initial_delay = None
 
-            periodic = loopingcall.FixedIntervalLoopingCall(
-                self.periodic_tasks)
-            periodic.start(interval=self.periodic_interval,
-                           initial_delay=initial_delay)
-            self.timers.append(periodic)
+            self.tg.add_timer(self.periodic_interval, self.periodic_tasks,
+                              initial_delay=initial_delay)
 
     def _create_service_ref(self, context):
         service_args = {
             'host': self.host,
             'binary': self.binary,
             'topic': self.topic,
+            'state': 'up',
             'report_count': 0,
             'availability_zone': self.availability_zone
         }
@@ -215,11 +253,13 @@ class Service(service.Service):
             self.rpcserver.stop()
         except Exception:
             pass
-        for x in self.timers:
-            try:
-                x.stop()
-            except Exception:
-                pass
+
+        try:
+            db.service_update(context.get_admin_context(),
+                              self.service_id, {'state': 'stopped'})
+        except exception.NotFound:
+            LOG.warning('Service stopped that has no database entry.')
+
         if self.coordinator:
             try:
                 coordination.LOCK_COORDINATOR.stop()
@@ -227,16 +267,12 @@ class Service(service.Service):
                 LOG.exception("Unable to stop the Tooz Locking "
                               "Coordinator.")
 
-        self.timers = []
-
-        super(Service, self).stop()
+        super(Service, self).stop(graceful=True)
 
     def wait(self):
-        for x in self.timers:
-            try:
-                x.wait()
-            except Exception:
-                pass
+        if self.rpcserver:
+            self.rpcserver.wait()
+        super(Service, self).wait()
 
     def periodic_tasks(self, raise_on_error=False):
         """Tasks to be run at a periodic interval."""
@@ -269,8 +305,12 @@ class Service(service.Service):
                     service_ref['availability_zone']['name']):
                 state_catalog['availability_zone'] = self.availability_zone
 
-            db.service_update(ctxt,
-                              self.service_id, state_catalog)
+            if utils.service_is_up(service_ref):
+                state_catalog['state'] = 'up'
+            else:
+                if service_ref['state'] != 'stopped':
+                    state_catalog['state'] = 'down'
+            db.service_update(ctxt, self.service_id, state_catalog)
 
             # TODO(termie): make this pattern be more elegant.
             if getattr(self, 'model_disconnected', False):
@@ -283,6 +323,21 @@ class Service(service.Service):
                 self.model_disconnected = True
                 LOG.exception('model server went away')
 
+    def cleanup_services(self):
+        """Remove the stopped services of same topic from the datastore."""
+        ctxt = context.get_admin_context()
+        try:
+            services = db.service_get_all_by_topic(ctxt, self.topic)
+        except exception.NotFound:
+            LOG.debug('The service database object disappeared,'
+                      'Exiting from cleanup.')
+            return
+
+        for svc in services:
+            if (svc['state'] == 'stopped' and
+                    not utils.service_is_up(svc)):
+                db.service_destroy(ctxt, svc['id'])
+
 
 class WSGIService(service.ServiceBase):
     """Provides ability to launch API from a 'paste' configuration."""
@@ -301,7 +356,7 @@ class WSGIService(service.ServiceBase):
         if not rpc.initialized():
             rpc.init(CONF)
         self.app = self.loader.load_app(name)
-        self.host = getattr(CONF, '%s_listen' % name, "0.0.0.0")
+        self.host = getattr(CONF, '%s_listen' % name, "0.0.0.0")  # nosec B104
         self.port = getattr(CONF, '%s_listen_port' % name, 0)
         self.workers = getattr(CONF, '%s_workers' % name, None)
         self.use_ssl = getattr(CONF, '%s_use_ssl' % name, False)
@@ -311,6 +366,7 @@ class WSGIService(service.ServiceBase):
                 "greater than 1.  Input value ignored.", {'name': name})
             # Reset workers to default
             self.workers = None
+
         self.server = wsgi.Server(
             CONF,
             name,
@@ -350,6 +406,7 @@ class WSGIService(service.ServiceBase):
         :returns: None
 
         """
+        setup_profiler(self.name, self.host)
         if self.manager:
             self.manager.init_host()
         self.server.start()
