@@ -70,6 +70,8 @@ class LVMHelper(driver.ExecuteMixin):
             'total_capacity_gb': float(total_size),
             'free_capacity_gb': float(free_size),
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
+            'reserved_share_extend_percentage': 0,
         }, ]
 
     def _get_lv_device(self, share_name):
@@ -229,7 +231,7 @@ class LVMHelper(driver.ExecuteMixin):
             'nondisruptive': None,
             'preserve_snapshots': None,
             'migration_cancel': None,
-            'migration_get_progress': None
+            'migration_get_progress': None,
         }
 
         dest_backend_name = share_utils.extract_host(dest_host,
@@ -274,7 +276,7 @@ class LVMHelper(driver.ExecuteMixin):
             'nondisruptive': False,
             'preserve_snapshots': False,
             'migration_cancel': True,
-            'migration_get_progress': True
+            'migration_get_progress': True,
         }
 
     def share_server_migration_start(self, context, src_share_server,
