@@ -16,7 +16,6 @@
 
 import copy
 import random
-import six
 
 from oslo_config import cfg
 from oslo_log import log
@@ -48,14 +47,11 @@ LOG = log.getLogger(__name__)
 
 VNX_OPTS = [
     cfg.StrOpt('vnx_server_container',
-               deprecated_name='emc_nas_server_container',
                help='Data mover to host the NAS server.'),
     cfg.ListOpt('vnx_share_data_pools',
-                deprecated_name='emc_nas_pool_names',
                 help='Comma separated list of pools that can be used to '
                      'persist share data.'),
     cfg.ListOpt('vnx_ethernet_ports',
-                deprecated_name='emc_interface_ports',
                 help='Comma separated list of ports that can be used for '
                      'share server interfaces. Members of the list '
                      'can be Unix-style glob expressions.')
@@ -81,9 +77,15 @@ class VNXStorageConnection(driver.StorageConnection):
         self.manager = None
         self.pool_conf = None
         self.reserved_percentage = None
+        self.reserved_snapshot_percentage = None
+        self.reserved_share_extend_percentage = None
         self.driver_handles_share_servers = True
         self.port_conf = None
         self.ipv6_implemented = True
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
 
     def create_share(self, context, share, share_server=None):
         """Create a share and export it based on protocol used."""
@@ -587,6 +589,16 @@ class VNXStorageConnection(driver.StorageConnection):
         if self.reserved_percentage is None:
             self.reserved_percentage = 0
 
+        self.reserved_snapshot_percentage = config.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if self.reserved_snapshot_percentage is None:
+            self.reserved_snapshot_percentage = self.reserved_percentage
+
+        self.reserved_share_extend_percentage = config.safe_get(
+            'reserved_share_extend_percentage')
+        if self.reserved_share_extend_percentage is None:
+            self.reserved_share_extend_percentage = self.reserved_percentage
+
         self.manager = manager.StorageObjectManager(config)
         self.port_conf = config.safe_get('vnx_ethernet_ports')
 
@@ -635,6 +647,10 @@ class VNXStorageConnection(driver.StorageConnection):
                         total_size - used_size),
                     qos=False,
                     reserved_percentage=self.reserved_percentage,
+                    reserved_snapshot_percentage=(
+                        self.reserved_snapshot_percentage),
+                    reserved_share_extend_percentage=(
+                        self.reserved_share_extend_percentage),
                 )
                 stats_dict['pools'].append(pool_stat)
 
@@ -716,7 +732,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
                 if ip_version == 6:
                     interface['ip_version'] = ip_version
-                    interface['net_mask'] = six.text_type(
+                    interface['net_mask'] = str(
                         utils.cidr_to_prefixlen(network_info['cidr']))
                 else:
                     interface['net_mask'] = utils.cidr_to_netmask(
