@@ -21,14 +21,14 @@ import re
 import shutil
 import string
 import tempfile
-import xml.etree.cElementTree as etree
 
+from defusedxml import ElementTree as etree
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from manila import exception
 from manila.i18n import _
+from manila.privsep import os as privsep_os
 from manila.share.drivers.glusterfs import common
 from manila.share.drivers.glusterfs import layout
 from manila import utils
@@ -39,7 +39,6 @@ LOG = log.getLogger(__name__)
 glusterfs_volume_mapped_opts = [
     cfg.ListOpt('glusterfs_servers',
                 default=[],
-                deprecated_name='glusterfs_targets',
                 help='List of GlusterFS servers that can be used to create '
                      'shares. Each GlusterFS server should be of the form '
                      '[remoteuser@]<volserver>, and they are assumed to '
@@ -126,7 +125,7 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
                 glusterfs_versions[srvaddr] = self._glustermanager(
                     srvaddr, False).get_gluster_version()
             except exception.GlusterfsException as exc:
-                exceptions[srvaddr] = six.text_type(exc)
+                exceptions[srvaddr] = str(exc)
         if exceptions:
             for srvaddr, excmsg in exceptions.items():
                 LOG.error("'gluster version' failed on server "
@@ -141,7 +140,7 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
                 notsupp_servers.append(srvaddr)
         if notsupp_servers:
             gluster_version_min_str = '.'.join(
-                six.text_type(c) for c in self.driver.GLUSTERFS_VERSION_MIN)
+                str(c) for c in self.driver.GLUSTERFS_VERSION_MIN)
             for srvaddr in notsupp_servers:
                 LOG.error("GlusterFS version %(version)s on server "
                           "%(server)s is not supported, "
@@ -354,17 +353,16 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
         # delete the paths of the two directories, but delete their contents
         # along with the rest of the contents of the volume.
         srvaddr = gluster_mgr.host_access
-        if common.numreduct(self.glusterfs_versions[srvaddr]) < (3, 7):
-            cmd = ['find', tmpdir, '-mindepth', '1', '-delete']
-        else:
+        ignored_dirs = []
+        if common.numreduct(self.glusterfs_versions[srvaddr]) > (3, 6):
             ignored_dirs = map(lambda x: os.path.join(tmpdir, *x),
                                [('.trashcan', ), ('.trashcan', 'internal_op')])
             ignored_dirs = list(ignored_dirs)
-            cmd = ['find', tmpdir, '-mindepth', '1', '!', '-path',
-                   ignored_dirs[0], '!', '-path', ignored_dirs[1], '-delete']
+            ignored_dirs = [ignored_dirs[0], ignored_dirs[1]]
 
         try:
-            self.driver._execute(*cmd, run_as_root=True)
+            privsep_os.find(
+                tmpdir, dirs_to_ignore=ignored_dirs, delete=True)
         except exception.ProcessExecutionError as exc:
             msg = (_("Error trying to wipe gluster volume. "
                      "gluster_export: %(export)s, Error: %(error)s") %
@@ -373,7 +371,7 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
             raise exception.GlusterfsException(msg)
         finally:
             # Unmount.
-            common._umount_gluster_vol(self.driver._execute, tmpdir)
+            common._umount_gluster_vol(tmpdir)
             shutil.rmtree(tmpdir, ignore_errors=True)
 
     def create_share(self, context, share, share_server=None):
@@ -435,9 +433,8 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
                 gmgr.set_vol_option(USER_MANILA_SHARE, 'NONE')
                 gmgr.set_vol_option('nfs.disable', 'on')
 
-            # When deleting the share instance, we need to
+            # When deleting the share instance, we may need to
             # update'self.gluster_used_vols' again
-            self.gluster_used_vols = set()
             self.gluster_used_vols.add(gmgr.qualified)
             self._push_gluster_vol(gmgr.qualified)
         except exception.GlusterfsException:
@@ -477,7 +474,7 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
         vers = self.glusterfs_versions[old_gmgr.host_access]
         minvers = (3, 7)
         if common.numreduct(vers) < minvers:
-            minvers_str = '.'.join(six.text_type(c) for c in minvers)
+            minvers_str = '.'.join(str(c) for c in minvers)
             vers_str = '.'.join(vers)
             msg = (_("GlusterFS version %(version)s on server %(server)s does "
                      "not support creation of shares from snapshot. "
@@ -492,9 +489,32 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
         backend_snapshot_name = self._find_actual_backend_snapshot_name(
             old_gmgr, snapshot)
         volume = ''.join(['manila-', share['id']])
-        args_tuple = (('snapshot', 'activate', backend_snapshot_name,
-                      'force', '--mode=script'),
-                      ('snapshot', 'clone', volume, backend_snapshot_name))
+
+        # Query the status of the snapshot, if it is Started, the activate
+        # step will be skipped
+        args = ('snapshot', 'info', backend_snapshot_name)
+        out, err = old_gmgr.gluster_call(
+            *args,
+            log=("Query the status of the snapshot"))
+
+        gfs_snapshot_state = ""
+        for gfs_snapshot_info in out.split('\t'):
+            gfs_snapshot_states = re.search(r'Started', gfs_snapshot_info,
+                                            re.I)
+            if gfs_snapshot_states:
+                gfs_snapshot_state = "Started"
+
+        if gfs_snapshot_state == "Started":
+            args_tuple = (('snapshot', 'clone',
+                          volume, backend_snapshot_name),
+                          ('volume', 'start', volume))
+        else:
+            args_tuple = (('snapshot', 'activate', backend_snapshot_name,
+                          'force', '--mode=script'),
+                          ('snapshot', 'clone', volume,
+                          backend_snapshot_name),
+                          ('volume', 'start', volume))
+
         for args in args_tuple:
             out, err = old_gmgr.gluster_call(
                 *args,
@@ -508,10 +528,10 @@ class GlusterfsVolumeMappedLayout(layout.GlusterfsShareLayoutBase):
             {'share': share, 'manager': gmgr},
             {'share': snapshot['share_instance'], 'manager': old_gmgr})
 
+        export = [export, ]
         argseq = (('set',
                    [USER_CLONED_FROM, snapshot['share_id']]),
-                  ('set', [USER_MANILA_SHARE, share['id']]),
-                  ('start', []))
+                  ('set', [USER_MANILA_SHARE, share['id']]))
         for op, opargs in argseq:
             args = ['volume', op, gmgr.volume] + opargs
             gmgr.gluster_call(*args, log=("Creating share from snapshot"))
