@@ -27,7 +27,7 @@ Configuration Requirements:
 
 import math
 import os
-import pipes
+import shlex
 import socket
 
 from oslo_concurrency import processutils
@@ -38,6 +38,7 @@ from oslo_utils import units
 from manila import exception
 from manila.i18n import _
 from manila.share import driver
+from manila import ssh_utils
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -54,6 +55,7 @@ hdfs_native_share_opts = [
     cfg.StrOpt('hdfs_ssh_name',
                help='HDFS namenode ssh login name.'),
     cfg.StrOpt('hdfs_ssh_pw',
+               secret=True,
                help='HDFS namenode SSH login password, '
                     'This parameter is not necessary, if '
                     '\'hdfs_ssh_private_key\' is configured.'),
@@ -113,7 +115,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         return self._run_ssh(host, cmd, check_exit_code)
 
     def _run_ssh(self, host, cmd_list, check_exit_code=False):
-        command = ' '.join(pipes.quote(cmd_arg) for cmd_arg in cmd_list)
+        command = ' '.join(shlex.quote(cmd_arg) for cmd_arg in cmd_list)
         connection = self.ssh_connections.get(host)
         if not connection:
             hdfs_ssh_name = self.configuration.hdfs_ssh_name
@@ -124,14 +126,14 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             min_size = self.configuration.ssh_min_pool_conn
             max_size = self.configuration.ssh_max_pool_conn
 
-            ssh_pool = utils.SSHPool(host,
-                                     hdfs_ssh_port,
-                                     ssh_conn_timeout,
-                                     hdfs_ssh_name,
-                                     password=password,
-                                     privatekey=privatekey,
-                                     min_size=min_size,
-                                     max_size=max_size)
+            ssh_pool = ssh_utils.SSHPool(host,
+                                         hdfs_ssh_port,
+                                         ssh_conn_timeout,
+                                         hdfs_ssh_name,
+                                         password=password,
+                                         privatekey=privatekey,
+                                         min_size=min_size,
+                                         max_size=max_size)
             ssh = ssh_pool.create()
             self.ssh_connections[host] = (ssh_pool, ssh)
         else:
