@@ -19,7 +19,6 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import excutils
 from oslo_utils import importutils
-import six
 
 from manila.common import constants
 from manila import exception
@@ -31,50 +30,39 @@ LOG = log.getLogger(__name__)
 
 hitachi_hnas_opts = [
     cfg.HostAddressOpt('hitachi_hnas_ip',
-                       deprecated_name='hds_hnas_ip',
                        help="HNAS management interface IP for communication "
                             "between Manila controller and HNAS."),
     cfg.StrOpt('hitachi_hnas_user',
-               deprecated_name='hds_hnas_user',
                help="HNAS username Base64 String in order to perform tasks "
                     "such as create file-systems and network interfaces."),
     cfg.StrOpt('hitachi_hnas_password',
-               deprecated_name='hds_hnas_password',
                secret=True,
                help="HNAS user password. Required only if private key is not "
                     "provided."),
     cfg.IntOpt('hitachi_hnas_evs_id',
-               deprecated_name='hds_hnas_evs_id',
                help="Specify which EVS this backend is assigned to."),
     cfg.HostAddressOpt('hitachi_hnas_evs_ip',
-                       deprecated_name='hds_hnas_evs_ip',
                        help="Specify IP for mounting shares."),
     cfg.HostAddressOpt('hitachi_hnas_admin_network_ip',
                        help="Specify IP for mounting shares in the Admin "
                             "network."),
     cfg.StrOpt('hitachi_hnas_file_system_name',
-               deprecated_name='hds_hnas_file_system_name',
                help="Specify file-system name for creating shares."),
     cfg.StrOpt('hitachi_hnas_ssh_private_key',
-               deprecated_name='hds_hnas_ssh_private_key',
                secret=True,
                help="RSA/DSA private key value used to connect into HNAS. "
                     "Required only if password is not provided."),
     cfg.HostAddressOpt('hitachi_hnas_cluster_admin_ip0',
-                       deprecated_name='hds_hnas_cluster_admin_ip0',
                        help="The IP of the clusters admin node. Only set in "
                             "HNAS multinode clusters."),
     cfg.IntOpt('hitachi_hnas_stalled_job_timeout',
-               deprecated_name='hds_hnas_stalled_job_timeout',
                default=30,
                help="The time (in seconds) to wait for stalled HNAS jobs "
                     "before aborting."),
     cfg.StrOpt('hitachi_hnas_driver_helper',
-               deprecated_name='hds_hnas_driver_helper',
                default='manila.share.drivers.hitachi.hnas.ssh.HNASSSHBackend',
                help="Python class to be used for driver helper."),
     cfg.BoolOpt('hitachi_hnas_allow_cifs_snapshot_while_mounted',
-                deprecated_name='hds_hnas_allow_cifs_snapshot_while_mounted',
                 default=False,
                 help="By default, CIFS snapshots are not allowed to be taken "
                      "when the share has clients connected because consistent "
@@ -169,7 +157,7 @@ class HitachiHNASDriver(driver.ShareDriver):
                            job_timeout)
 
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Update access rules for given share.
 
         :param context: The `context.RequestContext` object for the request
@@ -179,6 +167,8 @@ class HitachiHNASDriver(driver.ShareDriver):
             added. access_rules already contains these rules.
         :param delete_rules: Empty List or List of access rules which should be
             removed. access_rules doesn't contain these rules.
+        :param update_rules: Empty List or List of access rules which should be
+               updated. access_rules already contains these rules.
         :param share_server: Data structure with share server information.
             Not used by this driver.
         """
@@ -602,7 +592,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         LOG.info("Share %(shr_id)s successfully extended to "
                  "%(shr_size)s.",
                  {'shr_id': share['id'],
-                  'shr_size': six.text_type(new_size)})
+                  'shr_size': str(new_size)})
 
     # TODO(alyson): Implement in DHSS = true mode
     def get_network_allocations_number(self):
@@ -623,6 +613,10 @@ class HitachiHNASDriver(driver.ShareDriver):
         total_space, free_space, dedupe = self.hnas.get_stats()
 
         reserved = self.configuration.safe_get('reserved_share_percentage')
+        reserved_snapshot = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage') or reserved
+        reserved_share_extend = self.configuration.safe_get(
+            'reserved_share_extend_percentage') or reserved
 
         data = {
             'share_backend_name': self.backend_name,
@@ -633,6 +627,8 @@ class HitachiHNASDriver(driver.ShareDriver):
             'total_capacity_gb': total_space,
             'free_capacity_gb': free_space,
             'reserved_percentage': reserved,
+            'reserved_snapshot_percentage': reserved_snapshot,
+            'reserved_share_extend_percentage': reserved_share_extend,
             'qos': False,
             'thin_provisioning': True,
             'dedupe': dedupe,
@@ -641,7 +637,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         }
 
         LOG.info("HNAS Capabilities: %(data)s.",
-                 {'data': six.text_type(data)})
+                 {'data': str(data)})
 
         super(HitachiHNASDriver, self)._update_share_stats(data)
 
@@ -805,7 +801,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         LOG.info("Share %(shr_id)s successfully shrunk to "
                  "%(shr_size)sG.",
                  {'shr_id': share['id'],
-                  'shr_size': six.text_type(new_size)})
+                  'shr_size': str(new_size)})
 
     def revert_to_snapshot(self, context, snapshot, share_access_rules,
                            snapshot_access_rules, share_server=None):
