@@ -23,7 +23,6 @@ import re
 from oslo_config import cfg
 from oslo_config import types
 from oslo_log import log
-import six
 
 from manila.common import config
 from manila import exception
@@ -115,73 +114,59 @@ class FPG(types.String, types.IPAddress):
         return 'FPG'
 
     def _formatter(self, value):
-        return six.text_type(value)
+        return str(value)
 
 
 HPE3PAR_OPTS = [
     cfg.StrOpt('hpe3par_api_url',
                default='',
                help="3PAR WSAPI Server Url like "
-                    "https://<3par ip>:8080/api/v1",
-               deprecated_name='hp3par_api_url'),
+                    "https://<3par ip>:8080/api/v1"),
     cfg.StrOpt('hpe3par_username',
                default='',
-               help="3PAR username with the 'edit' role",
-               deprecated_name='hp3par_username'),
+               help="3PAR username with the 'edit' role"),
     cfg.StrOpt('hpe3par_password',
                default='',
                help="3PAR password for the user specified in hpe3par_username",
-               secret=True,
-               deprecated_name='hp3par_password'),
+               secret=True),
     cfg.HostAddressOpt('hpe3par_san_ip',
-                       help="IP address of SAN controller",
-                       deprecated_name='hp3par_san_ip'),
+                       help="IP address of SAN controller"),
     cfg.StrOpt('hpe3par_san_login',
                default='',
-               help="Username for SAN controller",
-               deprecated_name='hp3par_san_login'),
+               help="Username for SAN controller"),
     cfg.StrOpt('hpe3par_san_password',
                default='',
                help="Password for SAN controller",
-               secret=True,
-               deprecated_name='hp3par_san_password'),
+               secret=True),
     cfg.PortOpt('hpe3par_san_ssh_port',
                 default=22,
-                help='SSH port to use with SAN',
-                deprecated_name='hp3par_san_ssh_port'),
+                help='SSH port to use with SAN'),
     cfg.MultiOpt('hpe3par_fpg',
                  item_type=FPG(min_ip=0, max_ip=FPG.MAX_SUPPORTED_IP_PER_VFS),
-                 help="The File Provisioning Group (FPG) to use",
-                 deprecated_name='hp3par_fpg'),
+                 help="The File Provisioning Group (FPG) to use"),
     cfg.BoolOpt('hpe3par_fstore_per_share',
                 default=False,
-                help="Use one filestore per share",
-                deprecated_name='hp3par_fstore_per_share'),
+                help="Use one filestore per share"),
     cfg.BoolOpt('hpe3par_require_cifs_ip',
                 default=False,
                 help="Require IP access rules for CIFS (in addition to user)"),
     cfg.BoolOpt('hpe3par_debug',
                 default=False,
-                help="Enable HTTP debugging to 3PAR",
-                deprecated_name='hp3par_debug'),
+                help="Enable HTTP debugging to 3PAR"),
     cfg.StrOpt('hpe3par_cifs_admin_access_username',
                default='',
-               help="File system admin user name for CIFS.",
-               deprecated_name='hp3par_cifs_admin_access_username'),
+               help="File system admin user name for CIFS."),
     cfg.StrOpt('hpe3par_cifs_admin_access_password',
                default='',
                help="File system admin password for CIFS.",
-               secret=True,
-               deprecated_name='hp3par_cifs_admin_access_password'),
+               secret=True),
     cfg.StrOpt('hpe3par_cifs_admin_access_domain',
                default='LOCAL_CLUSTER',
-               help="File system domain for the CIFS admin user.",
-               deprecated_name='hp3par_cifs_admin_access_domain'),
+               help="File system domain for the CIFS admin user."),
     cfg.StrOpt('hpe3par_share_mount_path',
                default='/mnt/',
                help="The path where shares will be mounted when deleting "
-                    "nested file trees.",
-               deprecated_name='hpe3par_share_mount_path'),
+                    "nested file trees."),
 ]
 
 CONF = cfg.CONF
@@ -190,7 +175,7 @@ CONF.register_opts(HPE3PAR_OPTS)
 
 def to_list(var):
     """Convert var to list type if not"""
-    if isinstance(var, six.string_types):
+    if isinstance(var, str):
         return [var]
     else:
         return var
@@ -364,7 +349,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
             # with startup.  This is just debug info to identify the source
             # code.  If it doesn't work, just log a debug message.
             LOG.debug('Source code SHA1 not logged due to: %s',
-                      six.text_type(e))
+                      str(e))
 
     @staticmethod
     def sha1_hash(clazz):
@@ -372,7 +357,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
         source_file = inspect.getsourcefile(clazz)
         file_size = os.path.getsize(source_file)
 
-        sha1 = hashlib.sha1()
+        sha1 = hashlib.sha1(usedforsecurity=False)
         sha1.update(("blob %u\0" % file_size).encode('utf-8'))
 
         with open(source_file, 'rb') as f:
@@ -385,7 +370,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
 
     def choose_share_server_compatible_with_share(self, context, share_servers,
                                                   share, snapshot=None,
-                                                  share_group=None):
+                                                  share_group=None,
+                                                  encryption_key_ref=None):
         """Method that allows driver to choose share server for provided share.
 
         If compatible share-server is not found, method should return None.
@@ -447,6 +433,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
                 'vfs': vfs}
 
     def _setup_server(self, network_info, metadata=None):
+        # NOTE(felipe_rodrigues): keep legacy network_info support as a dict.
+        network_info = network_info[0]
 
         LOG.debug("begin _setup_server with %s", network_info)
 
@@ -565,7 +553,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
         pass
 
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Update access to the share."""
         extra_specs = None
         if 'NFS' == share['share_proto']:  # Avoiding DB call otherwise
@@ -620,6 +608,16 @@ class HPE3ParShareDriver(driver.ShareDriver):
         if reserved_share_percentage is None:
             reserved_share_percentage = 0
 
+        reserved_share_from_snapshot_percentage = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if reserved_share_from_snapshot_percentage is None:
+            reserved_share_from_snapshot_percentage = reserved_share_percentage
+
+        reserved_share_extend_percentage = self.configuration.safe_get(
+            'reserved_share_extend_percentage')
+        if reserved_share_extend_percentage is None:
+            reserved_share_extend_percentage = reserved_share_percentage
+
         stats = {
             'share_backend_name': backend_name,
             'driver_handles_share_servers': self.driver_handles_share_servers,
@@ -630,6 +628,10 @@ class HPE3ParShareDriver(driver.ShareDriver):
             'free_capacity_gb': 0,
             'provisioned_capacity_gb': 0,
             'reserved_percentage': reserved_share_percentage,
+            'reserved_snapshot_percentage':
+                reserved_share_from_snapshot_percentage,
+            'reserved_share_extend_percentage':
+                reserved_share_extend_percentage,
             'max_over_subscription_ratio': max_over_subscription_ratio,
             'qos': False,
             'thin_provisioning': True,  # 3PAR default is thin
@@ -643,6 +645,10 @@ class HPE3ParShareDriver(driver.ShareDriver):
             for fpg in self.fpgs:
                 fpg_status = self._hpe3par.get_fpg_status(fpg)
                 fpg_status['reserved_percentage'] = reserved_share_percentage
+                fpg_status['reserved_snapshot_percentage'] = (
+                    reserved_share_from_snapshot_percentage)
+                fpg_status['reserved_share_extend_percentage'] = (
+                    reserved_share_extend_percentage)
                 LOG.debug("FPG status = %s.", fpg_status)
                 stats.setdefault('pools', []).append(fpg_status)
 
