@@ -73,8 +73,9 @@ netapp_basicauth_opts = [
 
 netapp_certificateauth_opts = [
     cfg.StrOpt('netapp_private_key_file',
-               help=('Example: /path/to/private_key.key,'
-                     ' For self signed certificate: This file contains the'
+               sample_default='/path/to/private_key.key,',
+               regex=r'^/.+',
+               help=('For self signed certificate: This file contains the'
                      ' private key associated with the self-signed'
                      ' certificate. It is a sensitive file that should be'
                      ' kept secure and protected. The private key is used to'
@@ -87,13 +88,11 @@ netapp_certificateauth_opts = [
                      ' request (CSR) and should be kept secure and protected.'
                      ' The private key is used to sign the CSR and later used'
                      ' to establish secure connections and authenticate the'
-                     ' entity.'
-                     ' Please provide absolute path.'),
-               secret=True),
+                     ' entity.')),
     cfg.StrOpt('netapp_certificate_file',
-               help=('Example: /path/to/certificate.pem or'
-                     ' /path/to/certificate.crt,'
-                     ' For self signed certificate: This file contains the'
+               sample_default='/path/to/certificate.pem',
+               regex=r'^/.+',
+               help=('For self signed certificate: This file contains the'
                      ' self-signed digital certificate itself. It includes'
                      ' information about the entity such as the common name'
                      ' (e.g., domain name), organization details, validity'
@@ -108,26 +107,22 @@ netapp_certificateauth_opts = [
                      ' issued the certificate. The certificate file is used'
                      ' by clients or systems to verify the authenticity and'
                      ' integrity of the entity during the authentication'
-                     ' process.'
-                     ' Please provide absolute path.'),
-               secret=True),
+                     ' process.')),
     cfg.StrOpt('netapp_ca_certificate_file',
+               sample_default='/path/to/ca_certificate.crt',
+               regex=r'^/.+',
                help=('This is applicable only for ca verified certificate.'
-                     'Example: /path/to/ca_certificate.crt, This file'
-                     ' contains the public key certificate of the trusted'
-                     ' third-party certificate authority (CA) that issued the'
-                     ' certificate. It is used by clients or systems to'
-                     ' validate the authenticity of the certificate'
+                     ' This file contains the public key certificate of'
+                     ' the trusted third-party certificate authority (CA) that'
+                     ' issued the certificate. It is used by clients or '
+                     ' systems to validate the authenticity of the certificate'
                      ' presented by the entity. The CA certificate file'
                      ' is typically pre-configured in the trust store'
                      ' of clients or systems to establish trust in'
-                     ' certificates issued by that CA.'
-                     ' Please provide absolute path.'),
-               secret=True),
+                     ' certificates issued by that CA.')),
     cfg.BoolOpt('netapp_certificate_host_validation',
                 default=False,
-                help=('By default certificate verification is disabled and '
-                      'to verify please assign True to this option')), ]
+                help=('Enable certificate verification')), ]
 
 netapp_provisioning_opts = [
     cfg.ListOpt('netapp_enabled_share_protocols',
@@ -154,6 +149,9 @@ netapp_provisioning_opts = [
     cfg.StrOpt('netapp_lif_name_template',
                default='os_%(net_allocation_id)s',
                help='Logical interface (LIF) name template'),
+    cfg.StrOpt('netapp_identity_auth_token_path',
+               default='',
+               help='Path to interact with auth tokens'),
     cfg.StrOpt('netapp_aggregate_name_search_pattern',
                default='(.*)',
                help='Pattern for searching available aggregates '
@@ -186,6 +184,10 @@ netapp_provisioning_opts = [
                     "affect new shares, which will have their snapshot "
                     "directory always visible, unless toggled by the share "
                     "type extra spec 'netapp:hide_snapdir'."),
+    cfg.ListOpt('netapp_volume_snapshot_policy_exceptions',
+                help='NetApp volume Snapshot policy names which will not '
+                     'be overriden by extra-specs.',
+                default=['ec2_backups']),
     cfg.StrOpt('netapp_snapmirror_policy_name_svm_template',
                help='NetApp SnapMirror policy name template for Storage '
                     'Virtual Machines (Vservers).',
@@ -268,7 +270,16 @@ netapp_provisioning_opts = [
                      ' that can be migrated in case of failure, exceeds the '
                      'maximum data LIFs supported by the node. This option '
                      'guarantees that, in the event of a node failure, the'
-                     ' partner node will be able to takeover all data LIFs.')
+                     ' partner node will be able to takeover all data LIFs.'),
+    cfg.BoolOpt('netapp_cifs_aes_encryption',
+                default=False,
+                help='This option enable/disable AES encryption for the share'
+                     ' server based on the parameter value (True/False).'),
+    cfg.BoolOpt('netapp_enable_logical_space_reporting',
+                default=False,
+                help='This option enables the logical space reporting on a '
+                     'newly created vserver and logical space accounting '
+                     'on newly created volumes on this vserver. ')
 ]
 
 netapp_cluster_opts = [
