@@ -25,7 +25,6 @@ import math
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import units
-import six
 
 from manila.common import constants
 from manila import exception
@@ -59,6 +58,10 @@ quobyte_manila_share_opts = [
     cfg.StrOpt('quobyte_default_volume_group',
                default='root',
                help='Default owning group for new volumes.'),
+    cfg.StrOpt('quobyte_export_path',
+               default='/quobyte',
+               help='Export path for shares of this bacckend. This needs '
+                    'to match the quobyte-nfs services "Pseudo" option.'),
 ]
 
 CONF = cfg.CONF
@@ -79,9 +82,10 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         1.2.4   - Fixed handling updated QB API error codes
         1.2.5   - Fixed two quota handling bugs
         1.2.6   - Fixed volume resize and jsonrpc code style bugs
+        1.2.7   - Add quobyte_export_path option
     """
 
-    DRIVER_VERSION = '1.2.6'
+    DRIVER_VERSION = '1.2.7'
 
     def __init__(self, *args, **kwargs):
         super(QuobyteShareDriver, self).__init__(False, *args, **kwargs)
@@ -137,7 +141,13 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             driver_version=self.DRIVER_VERSION,
             total_capacity_gb=total_gb,
             free_capacity_gb=free_gb,
-            reserved_percentage=self.configuration.reserved_share_percentage)
+            reserved_percentage=self.configuration.reserved_share_percentage,
+            reserved_snapshot_percentage=(
+                self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage),
+            reserved_share_extend_percentage=(
+                self.configuration.reserved_share_extend_percentage
+                or self.configuration.reserved_share_percentage))
         super(QuobyteShareDriver, self)._update_share_stats(data)
 
     def _get_capacities(self):
@@ -247,7 +257,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
 
         self._resize_share(share, share['size'])
 
-        return '%(nfs_server_ip)s:%(nfs_export_path)s' % result
+        return self._build_share_export_string(result)
 
     def delete_share(self, context, share, share_server=None):
         """Delete the corresponding Quobyte volume."""
@@ -293,7 +303,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             volume_uuid=volume_uuid,
             protocol='NFS'))
 
-        return '%(nfs_server_ip)s:%(nfs_export_path)s' % result
+        return self._build_share_export_string(result)
 
     def _allow_access(self, context, share, access, share_server=None):
         """Allow access to a share."""
@@ -310,6 +320,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             "add_allow_ip": access['access_to']}
         self.rpc.call('exportVolume', call_params)
 
+    def _build_share_export_string(self, rpc_result):
+        return '%(nfs_server_ip)s:%(qb_exp_path)s%(nfs_export_path)s' % {
+            "nfs_server_ip": rpc_result["nfs_server_ip"],
+            "qb_exp_path": self.configuration.quobyte_export_path,
+            "nfs_export_path": rpc_result["nfs_export_path"]}
+
     def _deny_access(self, context, share, access, share_server=None):
         """Remove white-list ip from a share."""
         if access['access_type'] != 'ip':
@@ -349,7 +365,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         self._resize_share(share=shrink_share, new_size=shrink_size)
 
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Update access rules for given share.
 
         Two different cases are supported in here:
@@ -369,6 +385,8 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                added. access_rules already contains these rules.
         :param delete_rules: Empty List or List of access rules which should be
                removed. access_rules doesn't contain these rules.
+        :param update_rules: Empty List or List of access rules which should be
+               updated. access_rules already contains these rules.
         :param share_server: None or Share server model
         :raises If all of the *_rules params are None the method raises an
         InvalidShareAccess exception
@@ -390,12 +408,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                                                             existing_rules)
                 for a_rule in missing_rules:
                     LOG.debug("Adding rule %s in recovery.",
-                              six.text_type(a_rule))
+                              str(a_rule))
                     self._allow_access(context, share, a_rule)
 
                 superfluous_rules = self._subtract_access_lists(existing_rules,
                                                                 access_rules)
                 for d_rule in superfluous_rules:
                     LOG.debug("Removing rule %s in recovery.",
-                              six.text_type(d_rule))
+                              str(d_rule))
                     self._deny_access(context, share, d_rule)
