@@ -99,7 +99,6 @@ zfsonlinux_opts = [
              "storage host. Not used for replication operations. Optional."),
     cfg.ListOpt(
         "zfs_share_helpers",
-        required=True,
         default=[
             "NFS=manila.share.drivers.zfsonlinux.utils.NFSviaZFSHelper",
         ],
@@ -109,12 +108,10 @@ zfsonlinux_opts = [
              "Required."),
     cfg.StrOpt(
         "zfs_replica_snapshot_prefix",
-        required=True,
         default="tmp_snapshot_for_replication_",
         help="Set snapshot prefix for usage in ZFS replication. Required."),
     cfg.StrOpt(
         "zfs_migration_snapshot_prefix",
-        required=True,
         default="tmp_snapshot_for_share_migration_",
         help="Set snapshot prefix for usage in ZFS migration. Required."),
 ]
@@ -704,7 +701,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Updates access rules for given share."""
         dataset_name = self._get_dataset_name(share)
         executor = self._get_shell_executor_by_host(share['host'])
@@ -1127,7 +1124,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def promote_replica(self, context, replica_list, replica, access_rules,
-                        share_server=None):
+                        share_server=None, quiesce_wait_time=None):
         """Promotes secondary replica to active and active to secondary."""
         active_replica = self._get_active_replica(replica_list)
         src_dataset_name = self.private_storage.get(
