@@ -34,7 +34,7 @@ from manila import exception
 
 CONTEXT = context.get_admin_context()
 driver_opts = {}
-FAKE_UUID = 'aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa'
+FAKE_UUID = '123e4567-e89b-12d3-a456-426614174000'
 FAKE_UUIDS = {}
 host = 'host_name'
 identifier = '7cf7c200-d3af-4e05-b87e-9167c95dfcad'
@@ -86,7 +86,11 @@ class HTTPRequest(os_wsgi.Request):
     @classmethod
     def blank(cls, *args, **kwargs):
         if not kwargs.get('base_url'):
-            kwargs['base_url'] = 'http://localhost/v1'
+            method_url = args[0]
+            if method_url.startswith('/v2'):
+                kwargs['base_url'] = 'http://localhost/share/v2'
+            else:
+                kwargs['base_url'] = 'http://localhost/share/v1'
         use_admin_context = kwargs.pop('use_admin_context', False)
         version = kwargs.pop('version', api_version.DEFAULT_API_VERSION)
         experimental = kwargs.pop('experimental', False)
