@@ -19,6 +19,7 @@ import copy
 import ddt
 from oslo_config import cfg
 from oslo_serialization import jsonutils
+from oslo_utils import strutils
 from webob import exc
 
 from manila.api import common
@@ -38,11 +39,13 @@ CONF = cfg.CONF
 CAST_RULES_READONLY_VERSION = '2.30'
 PRE_GRADUATION_VERSION = '2.55'
 GRADUATION_VERSION = '2.56'
+PROMOTE_QUIESCE_WAIT_VERSION = '2.75'
 
 
 @ddt.ddt
 class ShareReplicasApiTest(test.TestCase):
     """Share Replicas API Test Cases."""
+
     def setUp(self):
         super(ShareReplicasApiTest, self).setUp()
         self.controller = share_replicas.ShareReplicationController()
@@ -396,11 +399,31 @@ class ShareReplicasApiTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.member_context, self.resource_name, 'create')
 
-    @ddt.data('2.72')
-    def test_create_invalid_network_id(self, microversion):
+    def test_create_has_been_encrypted(self):
+        share_ref = fake_share.fake_share(encryption_key_ref='fake')
+        body = {
+            'share_replica': {
+                'share_id': 'FAKE_SHAREID',
+                'availability_zone': 'FAKE_AZ'
+            }
+        }
+        mock__view_builder_call = self.mock_object(
+            share_replicas.replication_view.ReplicationViewBuilder,
+            'detail_list')
+        self.mock_object(share_replicas.db, 'share_get',
+                         mock.Mock(return_value=share_ref))
+
+        self.assertRaises(exc.HTTPForbidden,
+                          self.controller.create,
+                          self.replicas_req, body)
+        self.assertFalse(mock__view_builder_call.called)
+        self.mock_policy_check.assert_called_once_with(
+            self.member_context, self.resource_name, 'create')
+
+    def test_create_invalid_network_id(self):
         fake_replica, _ = self._get_fake_replica(
             replication_type='writable')
-        req = self._get_request(microversion, False)
+        req = self._get_request("2.72", False)
         req_context = req.environ['manila.context']
 
         body = {
@@ -419,7 +442,7 @@ class ShareReplicasApiTest(test.TestCase):
                          mock.Mock(side_effect=exception.ShareNetworkNotFound(
                                    share_network_id='FAKE_NETID')))
 
-        self.assertRaises(exc.HTTPNotFound,
+        self.assertRaises(exc.HTTPBadRequest,
                           self.controller.create,
                           req, body)
         self.assertFalse(mock__view_builder_call.called)
@@ -680,6 +703,42 @@ class ShareReplicasApiTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             context, self.resource_name, 'promote')
 
+    @ddt.data(('2.74', None),
+              (PROMOTE_QUIESCE_WAIT_VERSION, None),
+              (PROMOTE_QUIESCE_WAIT_VERSION, 10),
+              (PROMOTE_QUIESCE_WAIT_VERSION, 'foobar'),
+              )
+    @ddt.unpack
+    def test_promote_quiesce_wait_time(self, microversion, time):
+        body = {'promote': {'quiesce_wait_time': time}}
+        replica, expected_replica = self._get_fake_replica(
+            replica_state=constants.REPLICA_STATE_IN_SYNC,
+            microversion=microversion)
+        self.mock_object(share_replicas.db, 'share_replica_get',
+                         mock.Mock(return_value=replica))
+        self.mock_object(share_replicas.db, 'share_network_get',
+                         mock.Mock(return_value=self.fake_share_network))
+
+        req = self._get_request(microversion=microversion)
+        allow_quiesce_wait_time = False
+        if (api_version.APIVersionRequest(microversion) >=
+                api_version.APIVersionRequest(PROMOTE_QUIESCE_WAIT_VERSION)):
+            allow_quiesce_wait_time = True
+        if time and allow_quiesce_wait_time:
+            if strutils.is_int_like(time):
+                mock_api_promote_replica_call = self.mock_object(
+                    share.API, 'promote_share_replica',
+                    mock.Mock(return_value=replica))
+                resp = self.controller.promote(req, replica['id'], body)
+                self.assertEqual(expected_replica, resp['share_replica'])
+                self.assertTrue(mock_api_promote_replica_call.called)
+            else:
+                self.assertRaises(exc.HTTPBadRequest,
+                                  self.controller.promote,
+                                  req,
+                                  replica['id'],
+                                  body)
+
     @ddt.data('index', 'detail', '_show', '_create', '_delete_share_replica',
               '_promote', 'reset_replica_state', 'reset_status', '_resync')
     def test_policy_not_authorized(self, method_name):
@@ -785,6 +844,22 @@ class ShareReplicasApiTest(test.TestCase):
                            valid_code=valid_code, status_attr='replica_state',
                            valid_status=valid_status, body=body)
 
+    def test_reset_replica_with_active_state(self):
+        body = {
+            'reset_replica_state': {
+                'replica_state': constants.REPLICA_STATE_OUT_OF_SYNC,
+            }
+        }
+
+        replica, action_req = self._create_replica_get_req(
+            replica_state=constants.REPLICA_STATE_ACTIVE)
+
+        self._reset_status(self.admin_context, replica, action_req,
+                           status_attr='replica_state',
+                           valid_code=400,
+                           valid_status=constants.REPLICA_STATE_ACTIVE,
+                           body=body)
+
     @ddt.data(
         {'os-reset_replica_state': {'x-replica_state': 'bad'}},
         {'os-reset_replica_state': {'replica_state': constants.STATUS_ERROR}},
