@@ -14,13 +14,15 @@
 # under the License.
 
 import code
+import io
 import readline
 import sys
 from unittest import mock
+import yaml
 
 import ddt
 from oslo_config import cfg
-import six
+from oslo_serialization import jsonutils
 
 from manila.cmd import manage as manila_manage
 from manila import context
@@ -47,6 +49,8 @@ class ManilaCmdManageTestCase(test.TestCase):
         self.get_log_cmds = manila_manage.GetLogCommands()
         self.service_cmds = manila_manage.ServiceCommands()
         self.share_cmds = manila_manage.ShareCommands()
+        self.server_cmds = manila_manage.ShareServerCommands()
+        self.list_commands = manila_manage.ListCommand()
 
     @mock.patch.object(manila_manage.ShellCommands, 'run', mock.Mock())
     def test_shell_commands_bpython(self):
@@ -68,7 +72,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import bpython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed')
         self.shell_commands.run(**kwargs)
         bpython.embed.assert_called_once_with()
@@ -78,7 +82,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             import bpython
             import IPython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed',
                          mock.Mock(side_effect=ImportError()))
         self.mock_object(IPython, 'embed')
@@ -91,7 +95,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import bpython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(bpython, 'embed')
 
         self.shell_commands.run()
@@ -102,7 +106,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         try:
             import IPython
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(IPython, 'embed')
 
         self.shell_commands.run(shell='ipython')
@@ -117,7 +121,7 @@ class ManilaCmdManageTestCase(test.TestCase):
                 setattr(IPython.Shell, 'IPShell',
                         mock.Mock(side_effect=ImportError()))
         except ImportError as e:
-            self.skipTest(six.text_type(e))
+            self.skipTest(str(e))
         self.mock_object(IPython, 'embed',
                          mock.Mock(side_effect=ImportError()))
         self.mock_object(readline, 'parse_and_bind')
@@ -148,7 +152,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         readline.parse_and_bind.assert_called_once_with("tab:complete")
         code.interact.assert_called_once_with()
 
-    @mock.patch('six.moves.builtins.print')
+    @mock.patch('builtins.print')
     def test_list(self, print_mock):
         serv_1 = {
             'host': 'fake_host1',
@@ -170,7 +174,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             mock.call(u'host                     \tzone           '),
             mock.call('fake_host1               \tavail_zone1    ')])
 
-    @mock.patch('six.moves.builtins.print')
+    @mock.patch('builtins.print')
     def test_list_zone_is_none(self, print_mock):
         serv_1 = {
             'host': 'fake_host1',
@@ -221,7 +225,7 @@ class ManilaCmdManageTestCase(test.TestCase):
     def test_version_commands_list(self):
         self.mock_object(version, 'version_string',
                          mock.Mock(return_value='123'))
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             self.version_commands.list()
         version.version_string.assert_called_once_with()
         self.assertEqual('123\n', fake_out.getvalue())
@@ -229,13 +233,13 @@ class ManilaCmdManageTestCase(test.TestCase):
     def test_version_commands_call(self):
         self.mock_object(version, 'version_string',
                          mock.Mock(return_value='123'))
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             self.version_commands()
         version.version_string.assert_called_once_with()
         self.assertEqual('123\n', fake_out.getvalue())
 
     def test_get_log_commands_no_errors(self):
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             CONF.set_override('log_dir', None)
             expected_out = 'No errors in logfiles!\n'
 
@@ -243,14 +247,14 @@ class ManilaCmdManageTestCase(test.TestCase):
 
             self.assertEqual(expected_out, fake_out.getvalue())
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.listdir')
     def test_get_log_commands_errors(self, listdir, open):
         CONF.set_override('log_dir', 'fake-dir')
         listdir.return_value = ['fake-error.log']
 
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
-            open.return_value = six.StringIO(
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
+            open.return_value = io.StringIO(
                 '[ ERROR ] fake-error-message')
             expected_out = ('fake-dir/fake-error.log:-\n'
                             'Line 1 : [ ERROR ] fake-error-message\n')
@@ -260,7 +264,7 @@ class ManilaCmdManageTestCase(test.TestCase):
             open.assert_called_once_with('fake-dir/fake-error.log', 'r')
             listdir.assert_called_once_with(CONF.log_dir)
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     def test_get_log_commands_syslog_no_log_file(self, path_exists, open):
         path_exists.return_value = False
@@ -283,14 +287,14 @@ class ManilaCmdManageTestCase(test.TestCase):
                    'disabled': False}
         service_get_all.return_value = [service]
         service_is_up.return_value = True
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             format = "%-16s %-36s %-16s %-10s %-5s %-10s"
             print_format = format % ('Binary',
                                      'Host',
                                      'Zone',
                                      'Status',
                                      'State',
-                                     'Updated At')
+                                     'Updated at')
             service_format = format % (service['binary'],
                                        service['host'].partition('.')[0],
                                        service['availability_zone']['name'],
@@ -298,12 +302,47 @@ class ManilaCmdManageTestCase(test.TestCase):
                                        ':-)',
                                        service['updated_at'])
             expected_out = print_format + '\n' + service_format + '\n'
-            self.service_cmds.list()
+            self.service_cmds.list(format_output='table')
             self.assertEqual(expected_out, fake_out.getvalue())
             get_admin_context.assert_called_with()
             service_get_all.assert_called_with(ctxt)
             service_is_up.assert_called_with(service)
 
+    @ddt.data('json', 'yaml')
+    def test_service_commands_list_format(self, format_output):
+        ctxt = context.RequestContext('fake-user', 'fake-project')
+        format_method_name = f'list_{format_output}'
+        mock_list_method = self.mock_object(
+            self.service_cmds, format_method_name)
+        get_admin_context = self.mock_object(context, 'get_admin_context')
+        service_get_all = self.mock_object(db, 'service_get_all')
+        service_is_up = self.mock_object(utils, 'service_is_up')
+        get_admin_context.return_value = ctxt
+        service = {'binary': 'manila-binary',
+                   'host': 'fake-host.fake-domain',
+                   'availability_zone': {'name': 'fake-zone'},
+                   'updated_at': '2014-06-30 11:22:33',
+                   'disabled': False}
+        services = [service]
+        service_get_all.return_value = services
+        service_is_up.return_value = True
+
+        with mock.patch('sys.stdout', new=io.StringIO()):
+            self.service_cmds.list(format_output=format_output)
+            get_admin_context.assert_called_with()
+            service_get_all.assert_called_with(ctxt)
+            service_is_up.assert_called_with(service)
+            service_format = {
+                'binary': service['binary'],
+                'host': service['host'].partition('.')[0],
+                'zone': service['availability_zone']['name'],
+                'status': 'enabled',
+                'state': ':-)',
+                'updated_at': service['updated_at'],
+            }
+            mock_list_method.assert_called_once_with(
+                'services', [service_format])
+
     @ddt.data(True, False)
     def test_service_commands_cleanup(self, service_is_up):
         ctxt = context.RequestContext('fake-user', 'fake-project')
@@ -321,7 +360,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         self.mock_object(utils, 'service_is_up',
                          mock.Mock(return_value=service_is_up))
 
-        with mock.patch('sys.stdout', new=six.StringIO()) as fake_out:
+        with mock.patch('sys.stdout', new=io.StringIO()) as fake_out:
             if not service_is_up:
                 expected_out = "Cleaned up service %s" % service['host']
             else:
@@ -428,7 +467,7 @@ class ManilaCmdManageTestCase(test.TestCase):
         self.mock_object(db, 'share_resources_host_update',
                          mock.Mock(return_value=db_op))
 
-        with mock.patch('sys.stdout', new=six.StringIO()) as intercepted_op:
+        with mock.patch('sys.stdout', new=io.StringIO()) as intercepted_op:
             self.share_cmds.update_host(current_host, new_host, force)
 
         expected_op = ("Updated host of 3 share instances, 4 share groups and "
@@ -437,3 +476,117 @@ class ManilaCmdManageTestCase(test.TestCase):
         self.assertEqual(expected_op, intercepted_op.getvalue().strip())
         db.share_resources_host_update.assert_called_once_with(
             'admin_ctxt', current_host, new_host)
+
+    def test_share_delete(self):
+        share_id = "fake_share_id"
+        share = {
+            'id': share_id,
+            'instances': [
+                {'id': 'instance_id1', 'replica_state': 'active'},
+                {'id': 'instance_id2', 'replica_state': 'error'},
+                {'id': 'instance_id3', 'replica_state': 'active'},
+            ]
+        }
+        self.mock_object(context, 'get_admin_context',
+                         mock.Mock(return_value='admin_ctxt'))
+        self.mock_object(db, 'share_get',
+                         mock.Mock(return_value=share))
+        self.mock_object(db, 'share_instance_delete',
+                         mock.Mock(return_value=None))
+
+        self.share_cmds.delete(share_id)
+
+        db.share_instance_delete.assert_has_calls([
+            mock.call('admin_ctxt', 'instance_id2'),
+            mock.call('admin_ctxt', 'instance_id1'),
+            mock.call('admin_ctxt', 'instance_id3'),
+        ])
+
+        self.assertEqual(3, db.share_instance_delete.call_count)
+
+    def test_share_server_update_capability(self):
+        self.mock_object(context, 'get_admin_context',
+                         mock.Mock(return_value='admin_ctxt'))
+        self.mock_object(db, 'share_servers_update')
+        share_servers = 'server_id_a,server_id_b'
+        share_server_list = [server.strip()
+                             for server in share_servers.split(",")]
+        capabilities = "security_service_update_support" \
+                       ",network_allocation_update_support"
+        capabilities_list = capabilities.split(",")
+        values_to_update = [
+            {capabilities_list[0]: True,
+             capabilities_list[1]: True}]
+
+        with mock.patch('sys.stdout', new=io.StringIO()) as output:
+            self.server_cmds.update_share_server_capabilities(
+                share_servers, capabilities, True)
+
+        expected_op = ("The capability(ies) %(cap)s of the following share "
+                       "server(s) %(servers)s was(were) updated to "
+                       "%(value)s.") % {
+            'cap': capabilities_list,
+            'servers': share_server_list,
+            'value': True,
+        }
+
+        self.assertEqual(expected_op, output.getvalue().strip())
+        db.share_servers_update.assert_called_once_with(
+            'admin_ctxt', share_server_list, values_to_update[0])
+
+    def test_share_server_update_capability_not_supported(self):
+        share_servers = 'server_id_a'
+        capabilities = 'invalid_capability'
+
+        exit = self.assertRaises(
+            SystemExit,
+            self.server_cmds.update_share_server_capabilities,
+            share_servers,
+            capabilities,
+            True)
+
+        self.assertEqual(1, exit.code)
+
+    @mock.patch('builtins.print')
+    def test_list_commands_json(self, mock_print):
+        resource_name = 'service'
+        service_format = [{
+            'binary': 'manila-binary',
+            'host': 'fake-host',
+            'availability_zone': 'fakeaz',
+            'status': 'enabled',
+            'state': ':-)',
+            'updated_at': '13 04:57:49 PM -03 2023'
+        }]
+
+        mock_json_dumps = self.mock_object(
+            jsonutils, 'dumps', mock.Mock(return_value=service_format[0]))
+        services = {resource_name: service_format}
+
+        self.list_commands.list_json('service', service_format)
+
+        mock_json_dumps.assert_called_once_with(
+            services, indent=4)
+        mock_print.assert_called_once_with(service_format[0])
+
+    @mock.patch('builtins.print')
+    def test_list_commands_yaml(self, mock_print):
+        resource_name = 'service'
+        service_format = [{
+            'binary': 'manila-binary',
+            'host': 'fake-host',
+            'availability_zone': 'fakeaz',
+            'status': 'enabled',
+            'state': ':-)',
+            'updated_at': '13 04:57:49 PM -03 2023'
+        }]
+
+        mock_yaml_dump = self.mock_object(
+            yaml, 'dump', mock.Mock(return_value=service_format[0]))
+        services = {resource_name: service_format}
+
+        self.list_commands.list_yaml('service', service_format)
+
+        mock_yaml_dump.assert_called_once_with(
+            services)
+        mock_print.assert_called_once_with(service_format[0])
