@@ -24,13 +24,12 @@ from manila import context
 from manila import exception
 from manila import test
 from manila.tests import utils as test_utils
-from manila.volume import cinder
 
 
 class Volume(object):
     def __init__(self, volume_id):
         self.id = volume_id
-        self.name = volume_id
+        self.volumeId = volume_id
 
 
 class Network(object):
@@ -136,7 +135,7 @@ class NovaclientTestCase(test.TestCase):
         data = {
             'nova': {
                 'api_microversion': 'foo_api_microversion',
-                'endpoint_type': 'foo_endpoint_type',
+                'endpoint_type': 'internalURL',
                 'region_name': 'foo_region_name',
             }
         }
@@ -161,7 +160,7 @@ class NovaclientTestCase(test.TestCase):
         data = {
             'nova': {
                 'api_microversion': 'foo_api_microversion',
-                'endpoint_type': 'foo_endpoint_type',
+                'endpoint_type': 'internalURL',
                 'region_name': 'foo_region_name',
             }
         }
@@ -190,80 +189,6 @@ class NovaApiTestCase(test.TestCase):
         self.mock_object(nova, '_untranslate_server_summary_view',
                          lambda server: server)
 
-    def test_image_list_novaclient_has_no_proxy(self):
-        image_list = ['fake', 'image', 'list']
-
-        class FakeGlanceClient(object):
-            def list(self):
-                return image_list
-
-        self.novaclient.glance = FakeGlanceClient()
-
-        result = self.api.image_list(self.ctx)
-
-        self.assertEqual(image_list, result)
-
-    def test_image_list_novaclient_has_proxy(self):
-        image_list1 = ['fake', 'image', 'list1']
-        image_list2 = ['fake', 'image', 'list2']
-
-        class FakeImagesClient(object):
-            def list(self):
-                return image_list1
-
-        class FakeGlanceClient(object):
-            def list(self):
-                return image_list2
-
-        self.novaclient.images = FakeImagesClient()
-        self.novaclient.glance = FakeGlanceClient()
-
-        result = self.api.image_list(self.ctx)
-
-        self.assertEqual(image_list1, result)
-
-    def test_image_get_novaclient_has_no_proxy(self):
-        image = 'fake-image'
-
-        class FakeGlanceClient(object):
-            def find_image(self, name):
-                return image
-
-        self.novaclient.glance = FakeGlanceClient()
-        result = self.api.image_get(self.ctx, 'fake-image')
-
-        self.assertEqual(image, result)
-
-    def test_image_get_novaclient_not_found(self):
-        image = 'fake-image'
-
-        class FakeGlanceClient(object):
-            def find_image(self, image):
-                return image
-
-        self.novaclient.glance = FakeGlanceClient()
-
-        self.mock_object(self.novaclient.glance, 'find_image',
-                         mock.Mock(return_value=image,
-                                   side_effect=nova_exception.NotFound(404)))
-        self.assertRaises(exception.ServiceInstanceException,
-                          self.api.image_get, self.ctx, image)
-
-    def test_image_get_novaclient_multi_match(self):
-        image = 'fake-image'
-
-        class FakeGlanceClient(object):
-            def find_image(self, image):
-                return image
-
-        self.novaclient.glance = FakeGlanceClient()
-
-        self.mock_object(self.novaclient.glance, 'find_image',
-                         mock.Mock(return_value=image,
-                                   side_effect=nova_exception.NoUniqueMatch))
-        self.assertRaises(exception.ServiceInstanceException,
-                          self.api.image_get, self.ctx, image)
-
     def test_server_create(self):
         result = self.api.server_create(self.ctx, 'server_name', 'fake_image',
                                         'fake_flavor', None, None, None)
@@ -316,26 +241,6 @@ class NovaApiTestCase(test.TestCase):
         instance_id = 'instance_id'
         self.assertRaises(manila_e, self.api.server_get, self.ctx, instance_id)
 
-    def test_server_pause(self):
-        self.mock_object(self.novaclient.servers, 'pause')
-        self.api.server_pause(self.ctx, 'id1')
-        self.novaclient.servers.pause.assert_called_once_with('id1')
-
-    def test_server_unpause(self):
-        self.mock_object(self.novaclient.servers, 'unpause')
-        self.api.server_unpause(self.ctx, 'id1')
-        self.novaclient.servers.unpause.assert_called_once_with('id1')
-
-    def test_server_suspend(self):
-        self.mock_object(self.novaclient.servers, 'suspend')
-        self.api.server_suspend(self.ctx, 'id1')
-        self.novaclient.servers.suspend.assert_called_once_with('id1')
-
-    def test_server_resume(self):
-        self.mock_object(self.novaclient.servers, 'resume')
-        self.api.server_resume(self.ctx, 'id1')
-        self.novaclient.servers.resume.assert_called_once_with('id1')
-
     def test_server_reboot_hard(self):
         self.mock_object(self.novaclient.servers, 'reboot')
         self.api.server_reboot(self.ctx, 'id1')
@@ -348,13 +253,6 @@ class NovaApiTestCase(test.TestCase):
         self.novaclient.servers.reboot.assert_called_once_with(
             'id1', nova_servers.REBOOT_SOFT)
 
-    def test_server_rebuild(self):
-        self.mock_object(self.novaclient.servers, 'rebuild')
-        self.api.server_rebuild(self.ctx, 'id1', 'fake_image')
-        self.novaclient.servers.rebuild.assert_called_once_with('id1',
-                                                                'fake_image',
-                                                                None)
-
     def test_instance_volume_attach(self):
         self.mock_object(self.novaclient.volumes, 'create_server_volume')
         self.api.instance_volume_attach(self.ctx, 'instance_id',
@@ -373,13 +271,8 @@ class NovaApiTestCase(test.TestCase):
         self.mock_object(
             self.novaclient.volumes, 'get_server_volumes',
             mock.Mock(return_value=[Volume('id1'), Volume('id2')]))
-        self.cinderclient = self.novaclient
-        self.mock_object(cinder, 'cinderclient',
-                         mock.Mock(return_value=self.novaclient))
         result = self.api.instance_volumes_list(self.ctx, 'instance_id')
-        self.assertEqual(2, len(result))
-        self.assertEqual('id1', result[0].id)
-        self.assertEqual('id2', result[1].id)
+        self.assertEqual(['id1', 'id2'], result)
 
     def test_server_update(self):
         self.mock_object(self.novaclient.servers, 'update')
@@ -387,18 +280,6 @@ class NovaApiTestCase(test.TestCase):
         self.novaclient.servers.update.assert_called_once_with('id1',
                                                                name='new_name')
 
-    def test_update_server_volume(self):
-        self.mock_object(self.novaclient.volumes, 'update_server_volume')
-        self.api.update_server_volume(self.ctx, 'instance_id', 'att_id',
-                                      'new_vol_id')
-        (self.novaclient.volumes.update_server_volume.
-            assert_called_once_with('instance_id', 'att_id', 'new_vol_id'))
-
-    def test_keypair_create(self):
-        self.mock_object(self.novaclient.keypairs, 'create')
-        self.api.keypair_create(self.ctx, 'keypair_name')
-        self.novaclient.keypairs.create.assert_called_once_with('keypair_name')
-
     def test_keypair_import(self):
         self.mock_object(self.novaclient.keypairs, 'create')
         self.api.keypair_import(self.ctx, 'keypair_name', 'fake_pub_key')
