@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila import exception
@@ -80,7 +81,7 @@ class HitachiHSPTestCase(test.TestCase):
             side_effect=add_rule))
 
         self._driver.update_access('context', self.fake_share_instance, [],
-                                   access_list, [])
+                                   access_list, [], [])
 
         self.assertTrue(self.mock_log.debug.called)
 
@@ -112,7 +113,7 @@ class HitachiHSPTestCase(test.TestCase):
 
         self.assertRaises(exception.HSPBackendException,
                           self._driver.update_access, 'context',
-                          self.fake_share_instance, [], access_list, [])
+                          self.fake_share_instance, [], access_list, [], [])
 
         rest.HSPRestBackend.get_file_system.assert_called_once_with(
             self.fake_share_instance['id'])
@@ -146,7 +147,7 @@ class HitachiHSPTestCase(test.TestCase):
         self.mock_object(rest.HSPRestBackend, "add_access_rule")
 
         self._driver.update_access('context', self.fake_share_instance,
-                                   access_list, [], [])
+                                   access_list, [], [], [])
 
         self.assertTrue(self.mock_log.debug.called)
 
@@ -190,7 +191,7 @@ class HitachiHSPTestCase(test.TestCase):
                          mock.Mock(return_value=fakes.hsp_rules))
 
         self._driver.update_access('context', self.fake_share_instance, [], [],
-                                   delete_rules)
+                                   delete_rules, [])
 
         self.assertTrue(self.mock_log.debug.called)
 
@@ -230,7 +231,7 @@ class HitachiHSPTestCase(test.TestCase):
 
         self.assertRaises(exception.HSPBackendException,
                           self._driver.update_access, 'context',
-                          self.fake_share_instance, [], [], delete_rules)
+                          self.fake_share_instance, [], [], delete_rules, [])
 
         self.assertTrue(self.mock_log.debug.called)
 
@@ -261,9 +262,9 @@ class HitachiHSPTestCase(test.TestCase):
                          mock.Mock(return_value=fakes.hsp_rules))
 
         if is_recovery:
-            access_args = [access_list, [], []]
+            access_args = [access_list, [], [], []]
         else:
-            access_args = [[], access_list, []]
+            access_args = [[], access_list, [], []]
 
         self.assertRaises(exception.InvalidShareAccess,
                           self._driver.update_access, 'context',
@@ -286,7 +287,7 @@ class HitachiHSPTestCase(test.TestCase):
 
         self.assertRaises(exception.ShareResourceNotFound,
                           self._driver.update_access, 'context',
-                          self.fake_share_instance, access_list, [], [])
+                          self.fake_share_instance, access_list, [], [], [])
 
         rest.HSPRestBackend.get_file_system.assert_called_once_with(
             self.fake_share_instance['id'])
