@@ -746,6 +746,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
             'max_share_server_size': -1,
@@ -753,6 +754,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'security_service_update_support': False,
             'share_server_multiple_subnet_support': False,
             'network_allocation_update_support': False,
+            'share_replicas_migration_support': False,
+            'encryption_support': None,
         }
 
         result = self.driver.get_share_stats(refresh=True)
@@ -833,12 +836,15 @@ class HPE3ParDriverTestCase(test.TestCase):
             'share_server_multiple_subnet_support': False,
             'network_allocation_update_support': False,
             'mount_snapshot_support': False,
+            'share_replicas_migration_support': False,
+            'encryption_support': None,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
             },
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
         }
@@ -883,6 +889,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'security_service_update_support': False,
             'share_server_multiple_subnet_support': False,
             'network_allocation_update_support': False,
+            'share_replicas_migration_support': False,
+            'encryption_support': None,
             'mount_snapshot_support': False,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
@@ -890,6 +898,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'mount_point_name_support': False,
             'ipv4_support': True,
             'ipv6_support': False,
         }
