@@ -24,6 +24,7 @@ from manila import exception
 import manila.share.configuration as config
 from manila.share.drivers.maprfs import driver_util as mapru
 import manila.share.drivers.maprfs.maprfs_native as maprfs
+from manila import ssh_utils
 from manila import test
 from manila.tests import fake_share
 from manila import utils
@@ -298,7 +299,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver.update_access(self._context, self.share, [self.access],
-                                   [self.access], [])
+                                   [self.access], [], [])
 
         self._driver._maprfs_util._execute.assert_any_call(
             self.maprcli_bin, 'volume', 'modify', '-name', volume, '-readAce',
@@ -320,7 +321,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver.update_access(self._context, self.share, [self.access],
-                                   [self.access], [])
+                                   [self.access], [], [])
 
         self._driver._maprfs_util._execute.assert_any_call(
             self.maprcli_bin, 'volume', 'modify', '-name', volume, '-readAce',
@@ -341,7 +342,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver.update_access(self._context, self.share, [], [],
-                                   [self.access])
+                                   [self.access], [])
 
         self._driver._maprfs_util._execute.assert_any_call(
             self.maprcli_bin, 'volume', 'modify', '-name', volume, '-readAce',
@@ -363,7 +364,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver.update_access(self._context, self.share, [self.access],
-                                   [], [])
+                                   [], [], [])
 
         self._driver._maprfs_util._execute.assert_any_call(
             self.maprcli_bin, 'volume', 'modify', '-name', volume, '-readAce',
@@ -377,7 +378,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver.update_access(self._context, self.share, [self.access],
-                                   [], [])
+                                   [], [], [])
 
         self._driver._maprfs_util._execute.assert_not_called()
 
@@ -396,7 +397,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
 
         self.assertRaises(exception.MapRFSException,
                           self._driver.update_access, self._context,
-                          self.share, [self.access], [], [])
+                          self.share, [self.access], [], [], [])
 
     def test_update_access_invalid_access(self):
         access = fake_share.fake_access(access_type='ip', access_to='fake',
@@ -404,7 +405,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
 
         self.assertRaises(exception.InvalidShareAccess,
                           self._driver.update_access, self._context,
-                          self.share, [access], [], [])
+                          self.share, [access], [], [], [])
 
     def test_ensure_share(self):
         self._driver._maprfs_util.volume_exists = mock.Mock(
@@ -797,12 +798,14 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         ssh.get_transport().is_active = mock.Mock(return_value=False)
         ssh_pool = mock.Mock()
         ssh_pool.create = mock.Mock(return_value=ssh)
-        self.mock_object(utils, 'SSHPool', mock.Mock(return_value=ssh_pool))
+        self.mock_object(ssh_utils,
+                         'SSHPool',
+                         mock.Mock(return_value=ssh_pool))
         self.mock_object(processutils, 'ssh_execute',
                          mock.Mock(return_value=ssh_output))
         result = self._driver._maprfs_util._run_ssh(
             self.local_ip, cmd_list, check_exit_code=False)
-        utils.SSHPool.assert_called_once_with(
+        ssh_utils.SSHPool.assert_called_once_with(
             self._driver.configuration.maprfs_clinode_ip[0],
             self._driver.configuration.maprfs_ssh_port,
             self._driver.configuration.ssh_conn_timeout,
@@ -824,14 +827,16 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         ssh.get_transport().is_active = mock.Mock(return_value=True)
         ssh_pool = mock.Mock()
         ssh_pool.create = mock.Mock(return_value=ssh)
-        self.mock_object(utils, 'SSHPool', mock.Mock(return_value=ssh_pool))
+        self.mock_object(ssh_utils,
+                         'SSHPool',
+                         mock.Mock(return_value=ssh_pool))
         self.mock_object(processutils, 'ssh_execute', mock.Mock(
             side_effect=exception.ProcessExecutionError))
         self.assertRaises(exception.ProcessExecutionError,
                           self._driver._maprfs_util._run_ssh,
                           self.local_ip,
                           cmd_list)
-        utils.SSHPool.assert_called_once_with(
+        ssh_utils.SSHPool.assert_called_once_with(
             self._driver.configuration.maprfs_clinode_ip[0],
             self._driver.configuration.maprfs_ssh_port,
             self._driver.configuration.ssh_conn_timeout,
