@@ -42,6 +42,7 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
     def setUp(self):
         super(NetAppCDOTDataMotionTestCase, self).setUp()
         self.backend = 'backend1'
+        self.force_rest_client = False
         self.mock_cmode_client = self.mock_object(client_cmode,
                                                   "NetAppCmodeClient",
                                                   mock.Mock())
@@ -69,11 +70,11 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
                           group=self.backend)
         CONF.set_override("netapp_ssl_cert_path", "/etc/ssl/certs",
                           group=self.backend)
-        CONF.set_override("netapp_private_key_file", "fake_private_key.pem",
+        CONF.set_override("netapp_private_key_file", "/fake_private_key.pem",
                           group=self.backend)
-        CONF.set_override("netapp_certificate_file", "fake_cert.pem",
+        CONF.set_override("netapp_certificate_file", "/fake_cert.pem",
                           group=self.backend)
-        CONF.set_override("netapp_ca_certificate_file", "fake_ca_cert.crt",
+        CONF.set_override("netapp_ca_certificate_file", "/fake_ca_cert.crt",
                           group=self.backend)
         CONF.set_override("netapp_certificate_host_validation", False,
                           group=self.backend)
@@ -82,15 +83,16 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
         self.mock_object(data_motion, "get_backend_configuration",
                          mock.Mock(return_value=self.config))
 
-        data_motion.get_client_for_backend(self.backend)
+        data_motion.get_client_for_backend(self.backend,
+                                           self.force_rest_client)
 
         self.mock_cmode_client.assert_called_once_with(
             hostname='fake.hostname', password='fake_password',
             username='fake_user', transport_type='https', port=8866,
             ssl_cert_path='/etc/ssl/certs', trace=mock.ANY, vserver=None,
-            private_key_file='fake_private_key.pem',
-            certificate_file='fake_cert.pem',
-            ca_certificate_file='fake_ca_cert.crt',
+            private_key_file='/fake_private_key.pem',
+            certificate_file='/fake_cert.pem',
+            ca_certificate_file='/fake_ca_cert.crt',
             certificate_host_validation=False)
 
     def test_get_client_for_backend_with_vserver(self):
@@ -107,9 +109,9 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
             username='fake_user', transport_type='https', port=8866,
             ssl_cert_path='/etc/ssl/certs', trace=mock.ANY,
             vserver='fake_vserver',
-            private_key_file='fake_private_key.pem',
-            certificate_file='fake_cert.pem',
-            ca_certificate_file='fake_ca_cert.crt',
+            private_key_file='/fake_private_key.pem',
+            certificate_file='/fake_cert.pem',
+            ca_certificate_file='/fake_ca_cert.crt',
             certificate_host_validation=False)
 
     def test_get_client_for_host(self):
@@ -130,9 +132,12 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
 
     def test_get_config_for_backend(self):
         self.mock_object(data_motion, "CONF")
+
         CONF.set_override("netapp_vserver", 'fake_vserver',
                           group=self.backend)
-        data_motion.CONF.list_all_sections.return_value = [self.backend]
+
+        CONF.set_override("driver_handles_share_servers", False,
+                          group=self.backend)
 
         config = data_motion.get_backend_configuration(self.backend)
 
@@ -144,7 +149,9 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
                           group=self.backend)
         CONF.set_override("share_backend_name", "fake_backend_name",
                           group=self.backend)
-        data_motion.CONF.list_all_sections.return_value = [self.backend]
+
+        CONF.set_override("driver_handles_share_servers", False,
+                          group=self.backend)
 
         config = data_motion.get_backend_configuration(self.backend)
 
@@ -154,7 +161,6 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
     @ddt.data([], ['fake_backend1', 'fake_backend2'])
     def test_get_config_for_backend_not_configured(self, conf_sections):
         self.mock_object(data_motion, "CONF")
-        data_motion.CONF.list_all_sections.return_value = conf_sections
 
         self.assertRaises(exception.BadConfigurationException,
                           data_motion.get_backend_configuration,
