@@ -244,11 +244,11 @@ class GaneshaNASHelperTestCase(test.TestCase):
                                          self.access)
         self._helper.ganesha.get_export_id.assert_called_once_with()
         self._helper._fsal_hook.assert_called_once_with(
-            fake_basepath, self.share, self.access)
+            fake_basepath, self.share, self.access, sub_name=None)
         mock_ganesha_utils_patch.assert_called_once_with(
             {}, self._helper.export_template, fake_output_template)
         self._helper._fsal_hook.assert_called_once_with(
-            fake_basepath, self.share, self.access)
+            fake_basepath, self.share, self.access, sub_name=None)
         self._helper.ganesha.add_export.assert_called_once_with(
             fake_export_name, fake_output_template)
         self.assertIsNone(ret)
@@ -271,7 +271,7 @@ class GaneshaNASHelperTestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[self.access],
-            add_rules=[self.access], delete_rules=[])
+            add_rules=[self.access], delete_rules=[], update_rules=[])
 
         self._helper._allow_access.assert_called_once_with(
             '/', self.share, self.access)
@@ -286,7 +286,7 @@ class GaneshaNASHelperTestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[],
-            add_rules=[], delete_rules=[self.access])
+            add_rules=[], delete_rules=[self.access], update_rules=[])
 
         self._helper._deny_access.assert_called_once_with(
             '/', self.share, self.access)
@@ -301,7 +301,7 @@ class GaneshaNASHelperTestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[self.access],
-            add_rules=[], delete_rules=[])
+            add_rules=[], delete_rules=[], update_rules=[])
 
         self._helper._allow_access.assert_called_once_with(
             '/', self.share, self.access)
@@ -316,7 +316,8 @@ class GaneshaNASHelperTestCase(test.TestCase):
 
         result = self._helper.update_access(self._context, self.share,
                                             access_rules=[bad_rule],
-                                            add_rules=[], delete_rules=[])
+                                            add_rules=[], delete_rules=[],
+                                            update_rules=[])
 
         self.assertEqual(expected, result)
 
@@ -326,7 +327,8 @@ class GaneshaNASHelperTestCase(test.TestCase):
 
         result = self._helper.update_access(self._context, self.share,
                                             access_rules=[bad_rule],
-                                            add_rules=[], delete_rules=[])
+                                            add_rules=[], delete_rules=[],
+                                            update_rules=[])
 
         self.assertEqual(expected, result)
 
@@ -484,15 +486,16 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[self.rule1],
-            add_rules=[], delete_rules=[])
+            add_rules=[], delete_rules=[], update_rules=[])
 
         mock_gh.check_export_exists.assert_called_once_with('fakename')
         mock_gh.get_export_id.assert_called_once_with()
-        self._helper._get_export_path.assert_called_once_with(self.share)
+        self._helper._get_export_path.assert_called_once_with(
+            self.share, sub_name=None)
         (self._helper._get_export_pseudo_path.assert_called_once_with(
-            self.share))
+            self.share, sub_name=None))
         self._helper._fsal_hook.assert_called_once_with(
-            None, self.share, None)
+            None, self.share, None, sub_name=None)
         mock_gh.add_export.assert_called_once_with(
             'fakename', result_confdict)
         self.assertFalse(mock_gh.update_export.called)
@@ -520,7 +523,7 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[self.rule1, self.rule2],
-            add_rules=[self.rule2], delete_rules=[])
+            add_rules=[self.rule2], delete_rules=[], update_rules=[])
 
         mock_gh.check_export_exists.assert_called_once_with('fakename')
         mock_gh.update_export.assert_called_once_with('fakename',
@@ -541,12 +544,12 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[],
-            add_rules=[], delete_rules=[self.rule1])
+            add_rules=[], delete_rules=[self.rule1], update_rules=[])
 
         mock_gh.check_export_exists.assert_called_once_with('fakename')
         mock_gh.remove_export.assert_called_once_with('fakename')
         self._helper._cleanup_fsal_hook.assert_called_once_with(
-            None, self.share, None)
+            None, self.share, None, sub_name=None)
         self.assertFalse(mock_gh.add_export.called)
         self.assertFalse(mock_gh.update_export.called)
 
@@ -559,7 +562,7 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         self._helper.update_access(
             self._context, self.share, access_rules=[],
-            add_rules=[], delete_rules=[self.rule1])
+            add_rules=[], delete_rules=[self.rule1], update_rules=[])
 
         mock_gh.check_export_exists.assert_called_once_with('fakename')
         ganesha.LOG.warning.assert_called_once_with(mock.ANY, mock.ANY)
@@ -577,7 +580,8 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         result = self._helper.update_access(self._context, self.share,
                                             access_rules=[bad_rule],
-                                            add_rules=[], delete_rules=[])
+                                            add_rules=[], delete_rules=[],
+                                            update_rules=[])
 
         self.assertEqual(expected, result)
 
@@ -591,6 +595,7 @@ class GaneshaNASHelper2TestCase(test.TestCase):
 
         result = self._helper.update_access(self._context, self.share,
                                             access_rules=[bad_rule],
-                                            add_rules=[], delete_rules=[])
+                                            add_rules=[], delete_rules=[],
+                                            update_rules=[])
 
         self.assertEqual(expected, result)
