@@ -31,6 +31,7 @@ from manila import exception
 import manila.share.configuration
 from manila.share.drivers import generic
 from manila.share import share_types
+from manila import ssh_utils
 from manila import test
 from manila.tests import fake_compute
 from manila.tests import fake_service_instance
@@ -304,6 +305,7 @@ class GenericShareDriverTestCase(test.TestCase):
         server = {'instance_id': 'fake_server_id'}
         mount_path = self._driver._get_mount_path(self.share)
         volume = {'mountpoint': 'fake_mount_point'}
+        device_path = volume['mountpoint']
         self.mock_object(self._driver, '_is_device_mounted',
                          mock.Mock(return_value=False))
         self.mock_object(self._driver, '_add_mount_permanently')
@@ -315,7 +317,7 @@ class GenericShareDriverTestCase(test.TestCase):
         self._driver._is_device_mounted.assert_called_once_with(
             mount_path, server, volume)
         self._driver._add_mount_permanently.assert_called_once_with(
-            self.share.id, server)
+            self.share.id, device_path, server)
         self._driver._ssh_exec.assert_called_once_with(
             server, (
                 'sudo', 'mkdir', '-p', mount_path,
@@ -489,17 +491,29 @@ class GenericShareDriverTestCase(test.TestCase):
         self.assertFalse(result)
 
     def test_add_mount_permanently(self):
-        self.mock_object(self._driver, '_ssh_exec')
-        self._driver._add_mount_permanently(self.share.id, self.server)
+        device_path = '/fake/mount/path'
+        device_uuid = 'fake_disk_uuid'
+        formated_device_uuid = f"UUID={device_uuid}"
+        self.mock_object(self._driver, '_ssh_exec',
+                         mock.Mock(return_value=(device_uuid, '')))
+        self._driver._add_mount_permanently(self.share.id, device_path,
+                                            self.server)
         self._driver._ssh_exec.assert_has_calls([
             mock.call(
                 self.server,
                 ['grep', self.share.id, const.MOUNT_FILE_TEMP,
                  '|', 'sudo', 'tee', '-a', const.MOUNT_FILE]),
+            mock.call(self.server, ['lsblk', '-o', 'uuid',
+                      '-n', device_path]),
+            mock.call(
+                self.server,
+                ['sudo', 'sed', '-i', "s@{}@{}@".format(device_path,
+                 formated_device_uuid), const.MOUNT_FILE]),
             mock.call(self.server, ['sudo', 'mount', '-a'])
         ])
 
     def test_add_mount_permanently_raise_error_on_add(self):
+        device_path = 'fake_device_path'
         self.mock_object(
             self._driver, '_ssh_exec',
             mock.Mock(side_effect=exception.ProcessExecutionError))
@@ -507,6 +521,7 @@ class GenericShareDriverTestCase(test.TestCase):
             exception.ShareBackendException,
             self._driver._add_mount_permanently,
             self.share.id,
+            device_path,
             self.server
         )
         self._driver._ssh_exec.assert_called_once_with(
@@ -566,7 +581,7 @@ class GenericShareDriverTestCase(test.TestCase):
         fake_server = fake_compute.FakeServer()
         attached_volume = fake_volume.FakeVolume(status='in-use')
         self.mock_object(self._driver.compute_api, 'instance_volumes_list',
-                         mock.Mock(return_value=[attached_volume]))
+                         mock.Mock(return_value=[attached_volume.id]))
 
         result = self._driver._attach_volume(self._context, self.share,
                                              fake_server, attached_volume)
@@ -736,7 +751,7 @@ class GenericShareDriverTestCase(test.TestCase):
         self.mock_object(self._driver, '_get_volume',
                          mock.Mock(return_value=attached_volume))
         self.mock_object(self._driver.compute_api, 'instance_volumes_list',
-                         mock.Mock(return_value=[attached_volume]))
+                         mock.Mock(return_value=[attached_volume.id]))
         self.mock_object(self._driver.compute_api, 'instance_volume_detach')
         self.mock_object(self._driver.volume_api, 'get',
                          mock.Mock(return_value=available_volume))
@@ -1165,6 +1180,7 @@ class GenericShareDriverTestCase(test.TestCase):
         self._driver.update_access(self._context, self.share, access_rules,
                                    add_rules=add_rules,
                                    delete_rules=delete_rules,
+                                   update_rules=None,
                                    share_server=self.server)
 
         # asserts
@@ -1227,14 +1243,16 @@ class GenericShareDriverTestCase(test.TestCase):
         ssh.get_transport().is_active = mock.Mock(return_value=True)
         ssh_pool = mock.Mock()
         ssh_pool.create = mock.Mock(return_value=ssh)
-        self.mock_object(utils, 'SSHPool', mock.Mock(return_value=ssh_pool))
+        self.mock_object(ssh_utils,
+                         'SSHPool',
+                         mock.Mock(return_value=ssh_pool))
         self.mock_object(processutils, 'ssh_execute',
                          mock.Mock(return_value=ssh_output))
         self._driver.ssh_connections = {}
 
         result = self._driver._ssh_exec(self.server, cmd)
 
-        utils.SSHPool.assert_called_once_with(
+        ssh_utils.SSHPool.assert_called_once_with(
             self.server['ip'], 22, ssh_conn_timeout, self.server['username'],
             self.server['password'], self.server['pk_path'], max_size=1)
         ssh_pool.create.assert_called_once_with()
@@ -1494,10 +1512,8 @@ class GenericShareDriverTestCase(test.TestCase):
         self.mock_object(self._driver.volume_api, 'get',
                          mock.Mock(return_value=volume))
         self._driver.volume_api.update = mock.Mock()
-        fake_volume = mock.Mock()
-        fake_volume.id = 'fake'
         self.mock_object(self._driver.compute_api, 'instance_volumes_list',
-                         mock.Mock(return_value=[fake_volume]))
+                         mock.Mock(return_value=['fake']))
         self.mock_object(
             self._driver._helpers[share['share_proto']],
             'get_exports_for_share',
