@@ -256,11 +256,12 @@ class NFSHelperTestCase(test.TestCase):
     def test_get_host_list(self):
         fake_exportfs = ('/shares/share-1\n\t\t20.0.0.3\n'
                          '/shares/share-1\n\t\t20.0.0.6\n'
+                         '/shares/share-1\n\t\t<world>\n'
                          '/shares/share-2\n\t\t10.0.0.2\n'
                          '/shares/share-2\n\t\t10.0.0.5\n'
                          '/shares/share-3\n\t\t30.0.0.4\n'
                          '/shares/share-3\n\t\t30.0.0.7\n')
-        expected = ['20.0.0.3', '20.0.0.6']
+        expected = ['20.0.0.3', '20.0.0.6', '*']
         result = self._helper.get_host_list(fake_exportfs, '/shares/share-1')
         self.assertEqual(expected, result)
 
@@ -355,13 +356,16 @@ class NFSHelperTestCase(test.TestCase):
     @ddt.data(
         ('/shares/fake_share1\n\t\t1.1.1.10\n'
          '/shares/fake_share2\n\t\t1.1.1.16\n'
+         '/shares/fake_share3\n\t\t<world>\n'
          '/mnt/fake_share1 1.1.1.11', False),
         ('/shares/fake_share_name\n\t\t1.1.1.10\n'
          '/shares/fake_share_name\n\t\t1.1.1.16\n'
+         '/shares/fake_share_name\n\t\t<world>\n'
          '/mnt/fake_share1\n\t\t1.1.1.11', True),
         ('/mnt/fake_share_name\n\t\t1.1.1.11\n'
          '/shares/fake_share_name\n\t\t1.1.1.10\n'
-         '/shares/fake_share_name\n\t\t1.1.1.16\n', True))
+         '/shares/fake_share_name\n\t\t1.1.1.16\n'
+         '/shares/fake_share_name\n\t\t<world>\n', True))
     @ddt.unpack
     def test_disable_access_for_maintenance(self, output, hosts_match):
         fake_maintenance_path = "fake.path"
@@ -397,10 +401,15 @@ class NFSHelperTestCase(test.TestCase):
 
         if hosts_match:
             self._helper._ssh_exec.assert_has_calls([
-                mock.call(self.server, ['sudo', 'exportfs', '-u',
-                                        ':'.join(['1.1.1.10', local_path])]),
-                mock.call(self.server, ['sudo', 'exportfs', '-u',
-                                        ':'.join(['1.1.1.16', local_path])]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['1.1.1.10', local_path]))]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['1.1.1.16', local_path]))]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['*', local_path]))]),
             ])
 
         self._helper._sync_nfs_temp_and_perm_files.assert_called_once_with(
