@@ -144,6 +144,11 @@ class ManilaExceptionTestCase(test.TestCase):
         self.assertEqual(500, e.code)
         self.assertIn(reason, e.msg)
 
+    def test_ip_address_generation_failure(self):
+        # verify response code for exception.IpAddressGenerationFailureClient
+        e = exception.IpAddressGenerationFailureClient()
+        self.assertEqual(500, e.code)
+
 
 class ManilaExceptionResponseCode400(test.TestCase):
 
@@ -564,6 +569,13 @@ class ManilaExceptionResponseCode404(test.TestCase):
         self.assertEqual(404, e.code)
         self.assertIn(share_id, e.msg)
 
+    def test_resource_lock_not_found(self):
+        # verify response code for exception.ResourceLockNotFound
+        lock_id = "fake_lock_id"
+        e = exception.ResourceLockNotFound(lock_id=lock_id)
+        self.assertEqual(404, e.code)
+        self.assertIn(lock_id, e.msg)
+
 
 class ManilaExceptionResponseCode413(test.TestCase):
 
